@@ -29,12 +29,14 @@ from solentware_base.core.constants import (
     VEDIS_MODULE,
     GNU_MODULE,
     NDBM_MODULE,
+    DB_TCL_MODULE,
+    LMDB_MODULE,
 )
 
 APPLICATION_NAME = "ChessTab"
 ERROR_LOG = "ErrorLog"
 
-# bsddb3 interface module name
+# berkeleydb interface module name
 _BERKELEYDBCHESS = __name__ + ".berkeleydb.chessberkeleydb"
 
 # bsddb3 interface module name
@@ -61,6 +63,12 @@ _GNUCHESS = __name__ + ".gnu.chessgnu"
 # dbm.ndbm interface module name
 _NDBMCHESS = __name__ + ".ndbm.chessndbm"
 
+# tkinter.tcl Berkeley DB interface module name
+_DB_TCLCHESS = __name__ + ".db_tkinter.chessdbtkinter"
+
+# lmdb interface module name
+_LMDBCHESS = __name__ + ".lmdb.chesslmdb"
+
 # Map database module names to application module
 APPLICATION_DATABASE_MODULE = {
     BERKELEYDB_MODULE: _BERKELEYDBCHESS,
@@ -72,6 +80,8 @@ APPLICATION_DATABASE_MODULE = {
     VEDIS_MODULE: _VEDISCHESS,
     GNU_MODULE: _GNUCHESS,
     NDBM_MODULE: _NDBMCHESS,
+    DB_TCL_MODULE: _DB_TCLCHESS,
+    LMDB_MODULE: _LMDBCHESS,
 }
 
 # Default partial position dataset module name
@@ -91,6 +101,8 @@ PARTIAL_POSITION_MODULE = {
     VEDIS_MODULE: _DEFAULTPARTIALPOSITION,
     GNU_MODULE: _DEFAULTPARTIALPOSITION,
     NDBM_MODULE: _DEFAULTPARTIALPOSITION,
+    DB_TCL_MODULE: _DEFAULTPARTIALPOSITION,
+    LMDB_MODULE: _DEFAULTPARTIALPOSITION,
 }
 
 # Default full position dataset module name
@@ -110,6 +122,8 @@ FULL_POSITION_MODULE = {
     VEDIS_MODULE: _DEFAULTFULLPOSITION,
     GNU_MODULE: _DEFAULTFULLPOSITION,
     NDBM_MODULE: _DEFAULTFULLPOSITION,
+    DB_TCL_MODULE: _DEFAULTFULLPOSITION,
+    LMDB_MODULE: _DEFAULTFULLPOSITION,
 }
 
 # Default analysis dataset module name
@@ -129,6 +143,8 @@ ANALYSIS_MODULE = {
     VEDIS_MODULE: _DEFAULTANALYSIS,
     GNU_MODULE: _DEFAULTANALYSIS,
     NDBM_MODULE: _DEFAULTANALYSIS,
+    DB_TCL_MODULE: _DEFAULTANALYSIS,
+    LMDB_MODULE: _DEFAULTANALYSIS,
 }
 
 # Default selection rules dataset module name
@@ -148,4 +164,6 @@ SELECTION_MODULE = {
     VEDIS_MODULE: _DEFAULTSELECTION,
     GNU_MODULE: _DEFAULTSELECTION,
     NDBM_MODULE: _DEFAULTSELECTION,
+    DB_TCL_MODULE: _DEFAULTSELECTION,
+    LMDB_MODULE: _DEFAULTSELECTION,
 }
