@@ -14,7 +14,7 @@ class ChessapswduError(Exception):
     """Exception class for chessapswdu module."""
 
 
-def chess_sqlite3du(dbpath, *args, **kwargs):
+def chess_database_du(dbpath, *args, estimated_number_of_games=0, **kwargs):
     """Open database, import games and close database."""
     chess_du(ChessDatabase(dbpath, allowcreate=True), *args, **kwargs)
 
@@ -22,10 +22,6 @@ def chess_sqlite3du(dbpath, *args, **kwargs):
     return True
 
 
-# 'def chess_sqlite3du' will be changed to 'def chess_database_du' some time.
-chess_database_du = chess_sqlite3du
-
-
 class ChessDatabase(Alldu, Litedu, apswdu_database.Database):
     """Provide custom deferred update for a database of games of chess."""
 
