@@ -16,7 +16,7 @@ class ChessberkeleydbduError(Exception):
     """Exception class for chessberkeleydbdu module."""
 
 
-def chess_dbdu(dbpath, *args, **kwargs):
+def chess_database_du(dbpath, *args, estimated_number_of_games=0, **kwargs):
     """Open database, import games and close database."""
     chess_du(ChessDatabase(dbpath, allowcreate=True), *args, **kwargs)
 
@@ -24,15 +24,22 @@ def chess_dbdu(dbpath, *args, **kwargs):
     return True
 
 
-# 'def chess_dbdu' will be changed to 'def chess_database_du' at some time.
-chess_database_du = chess_dbdu
-
-
 class ChessDatabase(Alldu, Dbdu, berkeleydbdu_database.Database):
     """Provide custom deferred update for a database of games of chess."""
 
     def __init__(self, DBfile, **kargs):
         """Delegate with ChessberkeleydbduError as exception class."""
         super().__init__(
-            DBfile, ChessberkeleydbduError, berkeleydb.db, **kargs
+            DBfile,
+            ChessberkeleydbduError,
+            (
+                berkeleydb.db.DB_CREATE
+                | berkeleydb.db.DB_RECOVER
+                | berkeleydb.db.DB_INIT_MPOOL
+                | berkeleydb.db.DB_INIT_LOCK
+                | berkeleydb.db.DB_INIT_LOG
+                | berkeleydb.db.DB_INIT_TXN
+                | berkeleydb.db.DB_PRIVATE
+            ),
+            **kargs
         )
