@@ -13,7 +13,7 @@ if __name__ == "__main__":
 
     from . import APPLICATION_NAME
 
-    application_name = " ".join((APPLICATION_NAME, "(WineDPTMulti)"))
+    APP_NAME = " ".join((APPLICATION_NAME, "(WineDPTMulti)"))
     try:
         from solentware_misc.gui.startstop import (
             start_application_exception,
@@ -28,28 +28,35 @@ if __name__ == "__main__":
                 title="Start Exception",
                 message=".\n\nThe reported exception is:\n\n".join(
                     (
-                        "Unable to import solentware_misc.gui.startstop module",
+                        "".join(
+                            (
+                                "Unable to import ",
+                                "solentware_misc.gui.startstop module",
+                            )
+                        ),
                         str(error),
                     )
                 ),
             )
-        except:
+        except tkinter.TclError:
             pass
-        raise SystemExit("Unable to import start application utilities")
+        raise SystemExit(
+            "Unable to import start application utilities"
+        ) from error
     try:
         from .gui.chess import Chess
     except Exception as error:
-        start_application_exception(
-            error, appname=application_name, action="import"
-        )
-        raise SystemExit(" import ".join(("Unable to", application_name)))
+        start_application_exception(error, appname=APP_NAME, action="import")
+        raise SystemExit(" import ".join(("Unable to", APP_NAME))) from error
     try:
         app = Chess(allowcreate=True, dptmultistepdu=True)
     except Exception as error:
         start_application_exception(
-            error, appname=application_name, action="initialise"
+            error, appname=APP_NAME, action="initialise"
         )
-        raise SystemExit(" initialise ".join(("Unable to", application_name)))
+        raise SystemExit(
+            " initialise ".join(("Unable to", APP_NAME))
+        ) from error
     try:
         app.root.mainloop()
     except SystemExit:
@@ -60,6 +67,9 @@ if __name__ == "__main__":
             error,
             app,
             app.root,
-            title=application_name,
-            appname=application_name,
+            title=APP_NAME,
+            appname=APP_NAME,
         )
+        raise SystemExit(
+            " reporting exception in ".join(("Exception while", APP_NAME))
+        ) from error
