@@ -87,6 +87,9 @@ DB_ENVIRONMENT_GIGABYTES = 0
 DB_ENVIRONMENT_BYTES = 1024000
 DB_ENVIRONMENT_MAXLOCKS = 10000  # OpenBSD only.
 
+# Symas LMMD environment.
+LMMD_MINIMUM_FREE_PAGES_AT_START = 20000
+
 # Any partial position indexed by NEWGAMES_FIELD_VALUE on _NEWGAMES_FIELD_NAME
 # has not been recalculated since an update to the games file.  The partial
 # position's _PARTIALGAMES_FIELD_NAME reference on the games file is out of
