@@ -54,6 +54,7 @@ class GameDisplayMoves(GameIndicateCheck):
     """Add structures to support display of PGN moves."""
 
     def __init__(self):
+        """Delegate then initialize moves to empty list."""
         super().__init__()
         self.moves = []
 
@@ -87,10 +88,12 @@ class GameMove(Game):
     """
 
     def __init__(self):
+        """Delegate then set 'set initial position state' to None."""
         super().__init__()
         self._set_initial_position_state = None
 
     def set_initial_position(self):
+        """Return 'set initial position state' after delegate to initialize."""
         if self._set_initial_position_state is None:
             self._set_initial_position_state = super().set_initial_position()
         return self._set_initial_position_state
@@ -119,8 +122,8 @@ class GameAnalysis(GameDisplayMoves):
     def is_tag_roster_valid(self):
         """Return True if the game's tag roster is valid."""
         tags = self._tags
-        for v in tags.values():
-            if len(v) == 0:
+        for value in tags.values():
+            if len(value) == 0:
                 # Tag value must not be null
                 return False
         return True
@@ -151,15 +154,16 @@ def get_position_string(
     changing the order of those remaining.
 
     These values are intended as keys in an index and this structure puts keys
-    for similar positions, specifically for castling and en passant differences,
-    near each other.  En passant is before castling because the meaning of 'b',
-    'Q', and 'q', can be decided without using the 8 byte bit pattern: piece
-    name or en passant or castling or whose move.
+    for similar positions, specifically for castling and en passant
+    differences, near each other.  En passant is before castling because the
+    meaning of 'b', 'Q', and 'q', can be decided without using the 8 byte bit
+    pattern: piece name or en passant or castling or whose move.
 
     """
+    del halfmove_clock, fullmove_number
     squares = Squares.squares
-    for s, p in board.items():
-        p.set_square(s)
+    for square, piece in board.items():
+        piece.set_square(square)
     return (
         sum(squares[s].bit for s in board)
         .to_bytes(8, "big")
@@ -192,8 +196,8 @@ class GameRepertoireDisplayMoves(GameDisplayMoves):
     def is_tag_roster_valid(self):
         """Return True if the game's tag roster is valid."""
         tags = self._tags
-        for v in tags.values():
-            if len(v) == 0:
+        for value in tags.values():
+            if len(value) == 0:
                 # Tag value must not be null
                 return False
         if TAG_OPENING not in tags:
@@ -204,32 +208,46 @@ class GameRepertoireDisplayMoves(GameDisplayMoves):
     def get_repertoire_pgn(self):
         """Return export format PGN for repertoire."""
         tags = self._tags
-        pb = []
-        for t in REPERTOIRE_TAG_ORDER:
-            pb.extend(
-                ["[", t, ' "', tags.get(t, REPERTOIRE_GAME_TAGS[t]), '"]\n']
+        tokens = []
+        for tag in REPERTOIRE_TAG_ORDER:
+            tokens.extend(
+                [
+                    "[",
+                    tag,
+                    ' "',
+                    tags.get(tag, REPERTOIRE_GAME_TAGS[tag]),
+                    '"]\n',
+                ]
             )
-        for t, v in sorted(
+        for tag, value in sorted(
             [tv for tv in tags.items() if tv[0] not in REPERTOIRE_GAME_TAGS]
         ):
-            pb.extend(["[", t, ' "', v, '"]\n'])
-        pb.append(self.get_all_movetext_in_pgn_export_format())
-        return "".join(pb)
+            tokens.extend(["[", tag, ' "', value, '"]\n'])
+        tokens.append(self.get_all_movetext_in_pgn_export_format())
+        return "".join(tokens)
 
     def get_repertoire_pgn_no_comments(self):
         """Return export format PGN for repertoire excluding comments."""
         tags = self._tags
-        pb = []
-        for t in REPERTOIRE_TAG_ORDER:
-            pb.extend(
-                ["[", t, ' "', tags.get(t, REPERTOIRE_GAME_TAGS[t]), '"]\n']
+        tokens = []
+        for tag in REPERTOIRE_TAG_ORDER:
+            tokens.extend(
+                [
+                    "[",
+                    tag,
+                    ' "',
+                    tags.get(tag, REPERTOIRE_GAME_TAGS[tag]),
+                    '"]\n',
+                ]
             )
-        for t, v in sorted(
+        for tag, value in sorted(
             [tv for tv in tags.items() if tv[0] not in REPERTOIRE_GAME_TAGS]
         ):
-            pb.extend(["[", t, ' "', v, '"]\n'])
-        pb.append(self.get_movetext_without_comments_in_pgn_export_format())
-        return "".join(pb)
+            tokens.extend(["[", tag, ' "', value, '"]\n'])
+        tokens.append(
+            self.get_movetext_without_comments_in_pgn_export_format()
+        )
+        return "".join(tokens)
 
 
 class GameRepertoireUpdate(Game):
@@ -238,8 +256,8 @@ class GameRepertoireUpdate(Game):
     def is_tag_roster_valid(self):
         """Return True if the repertoire's tag roster is valid."""
         tags = self._tags
-        for v in tags.values():
-            if len(v) == 0:
+        for value in tags.values():
+            if len(value) == 0:
                 # Tag value must not be null
                 return False
         if TAG_OPENING not in tags:
@@ -257,16 +275,11 @@ class GameTags(Game):
     been disabled by overriding _collecting_movetext.  The definition ensures
     PGN._disambiguate_move is never called.
 
-    PGN._collecting_non_whitespace_while_searching is correct in this class too.
+    PGN._collecting_non_whitespace_while_searching is correct in this class
+    too.
 
     """
 
-    def append_token_and_set_error(self, match):
-        super().append_token_and_set_error(match)
-
-    def append_start_tag(self, match):
-        super().append_start_tag(match)
-
     def append_piece_move(self, match):
         """Ignore piece move token and update board state with null.
 
@@ -327,12 +340,6 @@ class GameTags(Game):
         except IndexError:
             self.add_board_state_none(None)
 
-    def ignore_move_number(self, match):
-        super().ignore_move_number(match)
-
-    def ignore_dots(self, match):
-        super().ignore_dots(match)
-
     def append_token(self, match):
         """Ignore valid non-tag token which does not change board state.
 
@@ -348,8 +355,7 @@ class GameTags(Game):
     append_reserved = append_token
 
     def append_start_rav(self, match):
-        """Append start recursive annotation variation token to game score and
-        update board state.
+        """Append start RAV token to game score and update board state.
 
         Put game in error state if a variation cannot be put at current place
         in game score.
@@ -364,8 +370,7 @@ class GameTags(Game):
         self._state_stack.append(self._state)
 
     def append_end_rav(self, match):
-        """Append end recursive annotation variation token to game score and
-        update board state.
+        """Append end RAV token to game score and update board state.
 
         Put game in error state if a variation cannot be finished at current
         place in game score.
@@ -373,14 +378,14 @@ class GameTags(Game):
         """
         if self._state is not None or self._movetext_offset is None:
             self.append_token_and_set_error(match)
-            return
+            return None
 
         if self._movetext_offset is None:
             self.append_token_and_set_error(match)
-            return
+            return None
         if len(self._ravstack) == 1:
             self.append_token_and_set_error(match)
-            return
+            return None
         del self._ravstack[-1]
         del self._state_stack[-1]
         self._state = self._state_stack[-1]
@@ -389,9 +394,6 @@ class GameTags(Game):
         self._text.append(match.group())
         return True
 
-    def ignore_escape(self, match):
-        super().ignore_escape(match)
-
     def append_other_or_disambiguation_pgn(self, match):
         """Ignore token.
 
@@ -414,17 +416,22 @@ class GameTags(Game):
         self._text.append(match.group())
 
     def append_start_rav_after_error(self, match):
-        """Append start RAV marker to game score and adjust error state for
-        recovery at end of recursive annotation variation in which error
-        occured.
+        """Append start RAV marker to game score and prepare error recovery.
+
+        Rest of RAV is assumed to be in error, but after next matching end
+        RAV marker it is worth assuming it possible to pick up from the
+        valid position just before this start RAV marker.
+
         """
         self._text.append(match.group())
         self._state_stack.append(self._state)
 
     def append_end_rav_after_error(self, match):
-        """Append start RAV marker to game score and adjust error state for
-        recovery at end of recursive annotation variation in which error
-        occured.
+        """Append end RAV marker to game score and reset position to pre-RAV.
+
+        It is assumed the pre-RAV position is valid (otherwise the error
+        state would have begun earlier).
+
         """
         if len(self._state_stack) > 1:
             if self._state_stack[-2] == self._state_stack[-1]:
@@ -462,8 +469,8 @@ class GameRepertoireTags(GameTags):
     def is_tag_roster_valid(self):
         """Return True if the game's tag roster is valid."""
         tags = self._tags
-        for v in tags.values():
-            if len(v) == 0:
+        for value in tags.values():
+            if len(value) == 0:
                 # Tag value must not be null
                 return False
         if TAG_OPENING not in tags:
@@ -478,6 +485,7 @@ class GameUpdate(Game):
     # self.positions, and the three similar, renamed to self.positionkeys.
     # self.movenumber is changed to self.halfmovenumber.
     def __init__(self):
+        """Delegate then prepare to collect positions and piece locations."""
         super().__init__()
         self.positionkeys = []
         self.piecesquaremovekeys = []
@@ -506,8 +514,7 @@ class GameUpdate(Game):
         )
 
     def reset_board_state(self, position_delta):
-        """Delegate to superclass then append initial variation number for this
-        level if it does not exist."""
+        """Delegate then append variation number to fit ravstack level."""
         super().reset_board_state(position_delta)
         if len(self._ravstack) > len(self.variationnumber):
             self.variationnumber.append(0)
@@ -516,9 +523,11 @@ class GameUpdate(Game):
     # came from PGNUpdate in chesstab, without the -1 adjustment, and seems to
     # work.
     def set_board_state(self, position_delta):
-        """Delegate to superclass then increment variation number and it's
-        string form in case there is another variation at this level.  For
-        example: '... Ba7 ) ( Nf4 ...'.
+        """Delegate then increment variation number.
+
+        Both numeric and string variation numbers are kept in step in case
+        there is another variation at this level.  For example:
+        '... Ba7 ) ( Nf4 ...'.
         """
         super().set_board_state(position_delta)
         self.variationnumber[len(self._ravstack) - 1] += 1
@@ -527,7 +536,7 @@ class GameUpdate(Game):
         )
 
     def modify_board_state(self, position_delta):
-        """Delegate to superclass then modify board state and add index entries."""
+        """Delegate then modify board state and add index entries."""
         super().modify_board_state(position_delta)
         if len(self._ravstack) != len(self.halfmovenumber):
             while len(self._ravstack) < len(self.halfmovenumber):
@@ -546,7 +555,7 @@ class GameUpdate(Game):
         squaremovekeys = self.squaremovekeys
         pieces = [""] * 64
         bits = []
-        mv = movenumber + self._variation
+        mnv = movenumber + self._variation
         for piece in self._piece_placement_data.values():
             piece_name = piece.name
             piece_square = piece.square
@@ -554,14 +563,14 @@ class GameUpdate(Game):
             pieces[piece_square.number] = piece_name
             bits.append(piece_square.bit)
 
-            # piecesquaremovekeys.append(mv + piece_name + square_name)
-            # squaremovekeys.append(mv + mp[piece_name] + square_name)
+            # piecesquaremovekeys.append(mnv + piece_name + square_name)
+            # squaremovekeys.append(mnv + mp[piece_name] + square_name)
 
             # If 'square piece' is better order than 'piece square'
-            piecesquaremovekeys.append(mv + square_name + piece_name)
+            piecesquaremovekeys.append(mnv + square_name + piece_name)
             squaremovekeys.append(
                 (
-                    mv
+                    mnv
                     + square_name
                     + MAP_PGN_PIECE_TO_CQL_COMPOSITE_PIECE[piece_name]
                 )
@@ -569,14 +578,14 @@ class GameUpdate(Game):
 
         pieces = "".join(pieces)
         for piece_name in set(pieces):
-            piecemovekeys.append(mv + piece_name)
-        bs = position_delta[1]
+            piecemovekeys.append(mnv + piece_name)
+        delta_after = position_delta[1]
         self.positionkeys.append(
             sum(bits).to_bytes(8, "big").decode("iso-8859-1")
             + pieces
-            + bs[1]
-            + bs[3]
-            + bs[2]
+            + delta_after[1]
+            + delta_after[3]
+            + delta_after[2]
         )
 
 
@@ -586,32 +595,33 @@ class GameUpdateEstimate(GameUpdate):
     start_char = 0
     end_char = 0
 
-    def __init__(self):
-        super().__init__()
-
     def append_start_tag(self, match):
-        if not len(self._tags):
+        """Set self.start_char if no PGN Tags found and delegate."""
+        if not self._tags:
             self.start_char = match.start()
         super().append_start_tag(match)
 
     def append_game_termination_after_error(self, match):
+        """Set self.end_char and delegate."""
         self.end_char = match.end()
         super().append_game_termination_after_error(match)
 
     def append_game_termination(self, match):
+        """Set self.end_char and delegate."""
         self.end_char = match.end()
         super().append_game_termination(match)
 
     def append_bad_tag_and_set_error(self, match):
-        if not len(self._tags):
+        """Set self.start_char if no PGN Tags found and delegate."""
+        if not self._tags:
             self.start_char = match.start()
         super().append_bad_tag_and_set_error(match)
 
 
-def _convert_integer_to_length_hex(i):
-    """Lookup conversion table or work it out if 'i' is not in lookup table."""
+def _convert_integer_to_length_hex(integer):
+    """Return hexadecimal representation of integer without '0x' prefix."""
     try:
-        return MOVE_NUMBER_KEYS[i]
+        return MOVE_NUMBER_KEYS[integer]
     except IndexError:
-        c = hex(i)
-        return str(len(c) - 2) + c[2:]
+        base16 = hex(integer)
+        return str(len(base16) - 2) + base16[2:]
