@@ -29,7 +29,7 @@ from solentware_grid.gui.dataedit import RecordEdit
 from solentware_grid.gui.datadelete import RecordDelete
 from solentware_grid.core.dataclient import DataNotify
 
-from solentware_misc.gui.exceptionhandler import ExceptionHandler
+from solentware_bind.gui.bindings import Bindings
 
 from .cql import CQL
 from .cqledit import CQLEdit
@@ -46,8 +46,11 @@ from .displaytext import (
 )
 
 
-class _CQLDisplay(ExceptionHandler, Display):
+class CQLDisplayListGamesError(Exception):
+    """Exception class for display of lists of games."""
 
+
+class _CQLDisplay(ShowText, DisplayText, CQL, Display, Bindings, DataNotify):
     """Extend and link ChessQL statement to database.
 
     sourceobject - link to database.
@@ -55,7 +58,7 @@ class _CQLDisplay(ExceptionHandler, Display):
     Attribute binding_labels specifies the order navigation bindings appear
     in popup menus.
 
-    Method insert_item_database allows records to be inserted into a database
+    Method _insert_item_database allows records to be inserted into a database
     from any CQL widget.
 
     """
@@ -89,27 +92,30 @@ class _CQLDisplay(ExceptionHandler, Display):
 
     @property
     def ui_displayed_items(self):
+        """Return manager of widgets displaying a partial position record."""
         return self.ui.partial_items
 
     @property
     def ui_configure_item_list_grid(self):
+        """Return function to configure partial position grid to fit text."""
         return self.ui.configure_partial_grid
 
     @property
     def ui_set_item_name(self):
-        return self.ui._set_partial_name
+        """Return function to set status bar text to name of active query."""
+        return self.ui.set_partial_name
 
     @property
     def ui_set_find_item_games(self):
-        return self.ui._set_find_partial_name_games
+        """Return function to set status bar text."""
+        return self.ui.set_find_partial_name_games
 
-    def get_navigation_events(self):
-        """Return event description tuple for navigation from selection rule
-        statement."""
+    def _get_navigation_events(self):
+        """Return event description tuple for navigation from query."""
         return (
             (EventSpec.navigate_to_partial_grid, self.set_focus_partial_grid),
-            (EventSpec.partialdisplay_to_previous_partial, self.prior_item),
-            (EventSpec.partialdisplay_to_next_partial, self.next_item),
+            (EventSpec.partialdisplay_to_previous_partial, self._prior_item),
+            (EventSpec.partialdisplay_to_next_partial, self._next_item),
             (
                 EventSpec.navigate_to_partial_game_grid,
                 self.set_focus_partial_game_grid,
@@ -140,7 +146,7 @@ class _CQLDisplay(ExceptionHandler, Display):
                 self.set_focus_selectionpanel_item,
             ),
             (EventSpec.navigate_to_game_grid, self.set_focus_game_grid),
-            (EventSpec.export_from_partialdisplay, self.export_partial),
+            (EventSpec.export_from_partialdisplay, self._export_partial),
             (EventSpec.tab_traverse_forward, self.traverse_forward),
             (EventSpec.tab_traverse_backward, self.traverse_backward),
             (EventSpec.tab_traverse_round, self.traverse_round),
@@ -148,10 +154,12 @@ class _CQLDisplay(ExceptionHandler, Display):
 
     def delete_item_view(self, event=None):
         """Remove ChessQL statement item from screen."""
+        del event
         self.ui.delete_position_view(self)
 
-    def insert_item_database(self, event=None):
+    def _insert_item_database(self, event=None):
         """Add ChessQL statement to database."""
+        del event
         if self.ui.partial_items.active_item is None:
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
@@ -187,7 +195,7 @@ class _CQLDisplay(ExceptionHandler, Display):
         updater.value.process_statement(self.get_name_cql_statement_text())
         title = "Insert ChessQL Statement"
         tname = title.replace("Insert ", "").replace("S", "s")
-        if not len(updater.value.get_name_text()):
+        if not updater.value.get_name_text():
             tkinter.messagebox.showerror(
                 parent=self.ui.get_toplevel(),
                 title=title,
@@ -261,19 +269,22 @@ class _CQLDisplay(ExceptionHandler, Display):
         instance is ignored: it is assumed a recalculation is needed.
 
         """
+        del instance
         if self.sourceobject is not None:
             self._get_cql_statement_games_to_grid(
                 self.cql_statement
             )  # .match)
 
     def generate_popup_navigation_maps(self):
-        navigation_map = {k: v for k, v in self.get_navigation_events()}
+        """Return genenal and current widget navigation binding maps."""
+        navigation_map = dict(self._get_navigation_events())
         local_map = {}
         return navigation_map, local_map
 
-    def create_primary_activity_popup(self):
-        popup = super().create_primary_activity_popup()
-        self.add_close_item_entry_to_popup(popup)
+    def _create_primary_activity_popup(self):
+        """Delegate then add close command to popup and return popup menu."""
+        popup = super()._create_primary_activity_popup()
+        self._add_close_item_entry_to_popup(popup)
         return popup
 
     def on_partial_change(self, instance):
@@ -313,8 +324,9 @@ class _CQLDisplay(ExceptionHandler, Display):
                     msg = "".join(
                         (
                             "Unable to add ChessQL statement to database, ",
-                            "probably because an 'empty square' is in the query ",
-                            "(eg '.a2-3'):\n\nThe reported  error is:\n\n",
+                            "probably because an 'empty square' is in the ",
+                            "query (eg '.a2-3'):\n\nThe reported  error ",
+                            "is:\n\n",
                             str(exc),
                         )
                     )
@@ -332,20 +344,6 @@ class _CQLDisplay(ExceptionHandler, Display):
                     message=msg,
                 )
                 return
-            except Exception as exc:
-                msg = "".join(
-                    (
-                        "Unable to add ChessQL statement to database:\n\n",
-                        "The reported error is:\n\n",
-                        str(exc),
-                    )
-                )
-                tkinter.messagebox.showinfo(
-                    parent=self.ui.get_toplevel(),
-                    title="Insert ChessQL Statement",
-                    message=msg,
-                )
-                return
         else:
 
             # Unfortunatly the existing list will have to be recalculated if
@@ -358,16 +356,17 @@ class _CQLDisplay(ExceptionHandler, Display):
                     msg = "".join(
                         (
                             "Unable to edit ChessQL statement on database, ",
-                            "probably because an 'empty square' is in the query ",
-                            "(eg '.a2-3'):\n\nThe reported  error is:\n\n",
+                            "probably because an 'empty square' is in the ",
+                            "query (eg '.a2-3'):\n\nThe reported  error ",
+                            "is:\n\n",
                             str(exc),
                         )
                     )
                 else:
                     msg = "".join(
                         (
-                            "Unable to edit ChessQL statement on database:\n\n",
-                            "The reported error is:\n\n",
+                            "Unable to edit ChessQL statement on database:",
+                            "\n\nThe reported error is:\n\n",
                             str(exc),
                         )
                     )
@@ -377,20 +376,6 @@ class _CQLDisplay(ExceptionHandler, Display):
                     message=msg,
                 )
                 return
-            except Exception as exc:
-                msg = "".join(
-                    (
-                        "Unable to edit ChessQL statement on database:\n\n",
-                        "The reported error is:\n\n",
-                        str(exc),
-                    )
-                )
-                tkinter.messagebox.showinfo(
-                    parent=self.ui.get_toplevel(),
-                    title="Insert ChessQL Statement",
-                    message=msg,
-                )
-                return
 
         if self is self.ui.partial_items.active_item:
             if self.sourceobject is not None and key == self.sourceobject.key:
@@ -403,7 +388,7 @@ class _CQLDisplay(ExceptionHandler, Display):
                 self._get_cql_statement_games_to_grid(value)
 
     def get_text_for_statusbar(self):
-        """ """
+        """Return 'Please wait ..' message for status bar."""
         return "".join(
             (
                 "Please wait while finding games for ChessQL statement ",
@@ -412,13 +397,13 @@ class _CQLDisplay(ExceptionHandler, Display):
         )
 
     def get_selection_text_for_statusbar(self):
-        """ """
+        """Return CQL query name text for display in status bar."""
         return self.cql_statement.get_name_text()
 
     def set_game_list(self):
         """Delegate to refresh_game_list via 'after(...) call."""
         self.panel.after(
-            0, func=self.try_command(self.ui._set_partial_name, self.panel)
+            0, func=self.try_command(self.ui.set_partial_name, self.panel)
         )
         self.panel.after(
             0, func=self.try_command(self.refresh_game_list, self.panel)
@@ -432,14 +417,16 @@ class _CQLDisplay(ExceptionHandler, Display):
         version 5.0 of CQL.  Thus "cql" is now a better name for the argument.
 
         """
-        p = self.ui.partial_games
-        if len(p.keys):
-            key = p.keys[0]
+        pgd = self.ui.partial_games
+        if len(pgd.keys):
+            key = pgd.keys[0]
         else:
             key = None
-        p.close_client_cursor()
+        pgd.close_client_cursor()
         try:
-            p.datasource.get_cql_statement_games(statement, self.sourceobject)
+            pgd.datasource.get_cql_statement_games(
+                statement, self.sourceobject
+            )
         except AttributeError as exc:
             if str(exc) == "'NoneType' object has no attribute 'answer'":
                 msg = "".join(
@@ -463,21 +450,9 @@ class _CQLDisplay(ExceptionHandler, Display):
                 title="Delete ChessQL Statement",
                 message=msg,
             )
-        except Exception as exc:
-            msg = "".join(
-                (
-                    "Unable to list games for ChessQL statement:\n\n",
-                    "The reported error is:\n\n",
-                    str(exc),
-                )
-            )
-            tkinter.messagebox.showinfo(
-                parent=self.ui.get_toplevel(),
-                title="Delete ChessQL Statement",
-                message=msg,
-            )
-        p.fill_view(currentkey=key, exclude=False)
-        if p.datasource.not_implemented:
+            return
+        pgd.fill_view(currentkey=key, exclude=False)
+        if pgd.datasource.not_implemented:
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
                 title="ChessQL Statement Not Implemented",
@@ -485,22 +460,22 @@ class _CQLDisplay(ExceptionHandler, Display):
                     (
                         "These filters are not implemented and ",
                         "are ignored:\n\n",
-                        "\n".join(sorted(grid.datasource.not_implemented)),
+                        "\n".join(sorted(pgd.datasource.not_implemented)),
                     )
                 ),
             )
 
 
-class CQLDisplay(_CQLDisplay, DisplayText, ShowText, CQL, DataNotify):
-
+class CQLDisplay(_CQLDisplay, CQL, DataNotify):
     """Display ChessQL statement from database and allow delete and insert.
 
-    Method delete_item_database allows records to be deleted from a database.
+    Method _delete_item_database allows records to be deleted from a database.
 
     """
 
-    def delete_item_database(self, event=None):
+    def _delete_item_database(self, event=None):
         """Remove ChessQL statement from database."""
+        del event
         if self.ui.database is None:
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
@@ -558,16 +533,16 @@ class CQLDisplay(_CQLDisplay, DisplayText, ShowText, CQL, DataNotify):
             message="Confirm request to delete ChessQL statement.",
         ):
             return
-        s = self.cql_statement
+        statement = self.cql_statement
 
         # Consider changing this since the call no longer ever returns None.
-        if s.is_statement() is not None:
+        if statement.is_statement() is not None:
 
-            v = self.sourceobject.value
+            value = self.sourceobject.value
             if (
-                s.get_name_text() != v.get_name_text()
-                or s.is_statement() != v.is_statement()
-                or s.get_statement_text() != v.get_statement_text()
+                statement.get_name_text() != value.get_name_text()
+                or statement.is_statement() != value.is_statement()
+                or statement.get_statement_text() != value.get_statement_text()
             ):
                 tkinter.messagebox.showinfo(
                     parent=self.ui.get_toplevel(),
@@ -577,8 +552,8 @@ class CQLDisplay(_CQLDisplay, DisplayText, ShowText, CQL, DataNotify):
                             "Cannot delete ChessQL statement.",
                             " ".join(
                                 (
-                                    "ChessQL statement on display is not same as",
-                                    "rule from record.",
+                                    "ChessQL statement on display is not",
+                                    "same as rule from record.",
                                 )
                             ),
                         )
@@ -602,9 +577,8 @@ class CQLDisplay(_CQLDisplay, DisplayText, ShowText, CQL, DataNotify):
 
 
 class CQLDisplayInsert(
-    _CQLDisplay, ListGamesText, InsertText, ShowText, CQLEdit, DataNotify
+    ListGamesText, InsertText, _CQLDisplay, CQLEdit, DataNotify
 ):
-
     """Display ChessQL statement from database allowing insert.
 
     CQLEdit provides the widget and _CQLDisplay the database interface.
@@ -619,37 +593,43 @@ class CQLDisplayInsert(
 
     """
 
-    def get_list_games_events(self):
+    def _get_list_games_events(self):
         """Return tuple of event bindings to list games for ChessQL rule."""
         return (
-            (EventSpec.display_list, self.process_and_set_cql_statement_list),
+            (EventSpec.display_list, self._process_and_set_cql_statement_list),
         )
 
-    def add_list_games_entry_to_popup(self, popup):
+    def _add_list_games_entry_to_popup(self, popup):
         """Add option to list games for selection rule to popup."""
-        self.set_popup_bindings(popup, self.get_list_games_events())
-
-    def set_database_navigation_close_item_bindings(self, switch=True):
-        super().set_database_navigation_close_item_bindings(switch=switch)
-        self.set_event_bindings_score(
-            self.get_list_games_events(), switch=switch
+        # index argument added when change in method resolution order caused
+        # this entry to be added after 'Close Item' rather than before.
+        self._set_popup_bindings(
+            popup, bindings=self._get_list_games_events(), index="Close Item"
         )
 
-    def process_and_set_cql_statement_list(self, event=None):
+    def _set_database_navigation_close_item_bindings(self, switch=True):
+        """Delegate then set list games event bindings."""
+        super()._set_database_navigation_close_item_bindings(switch=switch)
+        self.set_event_bindings_score(
+            self._get_list_games_events(), switch=switch
+        )
+
+    def _process_and_set_cql_statement_list(self, event=None):
         """Display games with position matching edited ChessQL statement."""
-        s = CQLStatement()
+        del event
+        statement = CQLStatement()
         # Not sure this is needed or wanted.
-        # s.dbset = self.ui.base_games.datasource.dbset
-        s.process_statement(self.get_name_cql_statement_text())
-        self.cql_statement = s
+        # statement.dbset = self.ui.base_games.datasource.dbset
+        statement.process_statement(self.get_name_cql_statement_text())
+        self.cql_statement = statement
         try:
             self.refresh_game_list()
         except AttributeError as exc:
             if str(exc) == "'NoneType' object has no attribute 'answer'":
                 msg = "".join(
                     (
-                        "Unable to list games for ChessQL statement, probably ",
-                        "because an 'empty square' is in the query ",
+                        "Unable to list games for ChessQL statement, ",
+                        "probably because an 'empty square' is in the query ",
                         "(eg '.a2-3'):\n\nThe reported  error is:\n\n",
                         str(exc),
                     )
@@ -667,32 +647,19 @@ class CQLDisplayInsert(
                 title="ChessQL Statement",
                 message=msg,
             )
-        except Exception as exc:
-            msg = "".join(
-                (
-                    "Unable to list games for ChessQL statement:\n\n",
-                    "The reported error is:\n\n",
-                    str(exc),
-                )
-            )
-            tkinter.messagebox.showinfo(
-                parent=self.ui.get_toplevel(),
-                title="ChessQL Statement",
-                message=msg,
-            )
         return "break"
 
 
 class CQLDisplayEdit(EditText, CQLDisplayInsert):
-
     """Display ChessQL statement from database allowing edit and insert.
 
-    Method update_item_database allows records on the database to be amended.
+    Method _update_item_database allows records on the database to be amended.
 
     """
 
-    def update_item_database(self, event=None):
+    def _update_item_database(self, event=None):
         """Modify existing ChessQL statement record."""
+        del event
         if self.ui.database is None:
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
@@ -751,7 +718,7 @@ class CQLDisplayEdit(EditText, CQLDisplayInsert):
         updater.value.process_statement(self.get_name_cql_statement_text())
         title = "Edit ChessQL Statement"
         tname = title.replace("Edit ", "").replace("S", "s")
-        if not len(updater.value.get_name_text()):
+        if not updater.value.get_name_text():
             tkinter.messagebox.showerror(
                 parent=self.ui.get_toplevel(),
                 title=title,
