@@ -2,7 +2,9 @@
 # Copyright 2021 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Provide classes which define methods shared by classes in gamedisplay and
+"""Provide classes which define set bindings and navigation methods.
+
+The methods in these classes are shared by classes in gamedisplay and
 repertoiredisplay modules which display Portable Game Notation (PGN) text.
 
 The gamedisplay module has two sets of classes: based on the _GameDisplay and
@@ -44,7 +46,6 @@ import tkinter.messagebox
 from solentware_grid.gui.dataedit import RecordEdit
 from solentware_grid.gui.datadelete import RecordDelete
 
-from .eventspec import EventSpec
 from .score import NonTagBind, ScoreNoGameException
 from .scorepgn import ScorePGN
 from .displaytext import ShowText, DisplayText, EditText, InsertText
@@ -54,18 +55,7 @@ from .displaytext import ShowText, DisplayText, EditText, InsertText
 # ShowText before ScorePGN because identical methods in ShowPGN and ShowText
 # are deleted from ShowPGN.
 class ShowPGN(ShowText, ScorePGN):
-
-    """Mixin providing methods shared by the gamedisplay._GameDisplay and
-    repertoiredisplay.RepertoreDisplay classes.
-
-    Provide focus switching and widget visibility methods for widgets which
-    display Portable Game Notation (PGN) text.
-
-    The gamedisplay.GameDialogue and repertoire.RepertoireDialogue classes
-    are used in a Toplevel which displays one game or repertoire.  The focus
-    switching provided here is not needed.
-
-    """
+    """Provide methods to set bindinds and traverse visible items."""
 
     # The methods identical except for docstrings.  Here 'PGN score' replaces
     # 'game' and 'repertoire'.  The method names already had 'item' rather
@@ -92,15 +82,14 @@ class ShowPGN(ShowText, ScorePGN):
     def bind_for_widget_navigation(self):
         """Set bindings to give focus to this PGN score on pointer click."""
         super().bind_for_widget_navigation()
-        self.set_board_pointer_widget_navigation_bindings(True)
+        self._set_board_pointer_widget_navigation_bindings(True)
         self.set_analysis_score_pointer_to_analysis_score_bindings(False)
         self.set_analysis_score_pointer_to_analysis_score_bindings(False)
 
-    # Probably becomes set_item(), but stays here rather than moved to each
+    # Probably becomes _set_item(), but stays here rather than moved to each
     # subclass: see displaytext.ShowText version.
     def set_and_tag_item_text(self, reset_undo=False):
         """Delegate to superclass method and set PGN score inactive."""
-
         # Superclass may set self._most_recent_bindings but test below must be
         # against current value.
         mrb = self._most_recent_bindings
@@ -110,39 +99,36 @@ class ShowPGN(ShowText, ScorePGN):
         except ScoreNoGameException:
             return
         if mrb != NonTagBind.NO_EDITABLE_TAGS:
-            for es in (self.get_inactive_button_events(),):
-                self.set_event_bindings_score(es, switch=True)
+            for event_spec in (self._get_inactive_button_events(),):
+                self.set_event_bindings_score(event_spec, switch=True)
 
-    def set_select_variation_bindings(self, switch=True):
-        """Delegate to toggle other relevant bindings and toggle bindings for
-        database actions, navigation to other widgets, and close widget.
-
-        """
-        super().set_select_variation_bindings(switch=switch)
-        self.set_database_navigation_close_item_bindings(switch=switch)
+    def _set_select_variation_bindings(self, switch=True):
+        """Delegate then set navigation and close item bindings."""
+        super()._set_select_variation_bindings(switch=switch)
+        self._set_database_navigation_close_item_bindings(switch=switch)
 
     # The methods identical except for docstrings, and references to
     # self.ui.game_items or self.ui.repertoire_items replaced by property
     # self.ui_displayed_items.
 
-    def next_item(self, event=None):
+    def _next_item(self, event=None):
         """Select next PGN score on display."""
         if self.ui_displayed_items.count_items_in_stack() > 1:
-            self.cycle_item(prior=False)
+            self._cycle_item(prior=False)
 
-    def prior_item(self, event=None):
+    def _prior_item(self, event=None):
         """Select previous PGN score on display."""
         if self.ui_displayed_items.count_items_in_stack() > 1:
-            self.cycle_item(prior=True)
+            self._cycle_item(prior=True)
 
     def traverse_backward(self, event=None):
         """Give focus to previous widget type in traversal order."""
-        self.set_board_pointer_widget_navigation_bindings(True)
+        self._set_board_pointer_widget_navigation_bindings(True)
         return super().traverse_backward(event=event)
 
     def traverse_forward(self, event=None):
         """Give focus to next widget type in traversal order."""
-        self.set_board_pointer_widget_navigation_bindings(True)
+        self._set_board_pointer_widget_navigation_bindings(True)
         return super().traverse_forward(event=event)
 
     def give_focus_to_widget(self, event=None):
@@ -163,19 +149,20 @@ class ShowPGN(ShowText, ScorePGN):
     # ui_base_table.  The clarity of both common bits and differences
     # seems to justify the extra syntactic complexity.
 
-    # Probably becomes insert_item_database(), but stays here rather than moved
-    # to each subclass: see displaytext.ShowText version.
-    def insert_item_database(self, event=None):
+    # Probably becomes _insert_item_database(), but stays here rather than
+    # moved to each subclass: see displaytext.ShowText version.
+    def _insert_item_database(self, event=None):
         """Add PGN score to database on request from item display."""
+        del event
         title = " ".join(("Insert", self.pgn_score_name.title()))
-        mt = self.pgn_score_name
+        psn = self.pgn_score_name
         if self.ui_displayed_items.active_item is None:
             tkinter.messagebox.showerror(
                 parent=self.ui.get_toplevel(),
                 title=title,
-                message=mt.join(("No active ", " to insert into database.")),
+                message=psn.join(("No active ", " to insert into database.")),
             )
-            return
+            return None
 
         # This should see if game with same PGN Tags already exists,
         # after checking for database open, and offer option to insert anyway.
@@ -183,48 +170,49 @@ class ShowPGN(ShowText, ScorePGN):
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
                 title=title,
-                message=mt.join(("Cannot add ", ":\n\nNo database open.")),
+                message=psn.join(("Cannot add ", ":\n\nNo database open.")),
             )
-            return
+            return None
 
         datasource = self.ui_base_table.get_data_source()
         if datasource is None:
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
                 title=title,
-                message=mt.join(("Cannot add ", ":\n\n", " list hidden.")),
+                message=psn.join(("Cannot add ", ":\n\n", " list hidden.")),
             )
-            return
+            return None
         if tkinter.messagebox.YES != tkinter.messagebox.askquestion(
             parent=self.ui.get_toplevel(),
             title=title,
-            message=mt.join(("Confirm request to add ", " to database")),
+            message=psn.join(("Confirm request to add ", " to database")),
         ):
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
                 title=title,
-                message=mt.join(("Add ", " to database abandonned.")),
+                message=psn.join(("Add ", " to database abandonned.")),
             )
-            return
-        updater = self.game_updater(repr(self.score.get("1.0", tkinter.END)))
+            return None
+        updater = self._game_updater(repr(self.score.get("1.0", tkinter.END)))
         if not updater.value.collected_game.is_pgn_valid():
             if tkinter.messagebox.YES != tkinter.messagebox.askquestion(
                 parent=self.ui.get_toplevel(),
                 title=title,
-                message=mt.join(
+                message=psn.join(
                     (
                         "The new ",
                         "".join(
                             (
-                                " score contains at least one illegal move in ",
-                                "PGN.\n\nPlease re-confirm request to insert ",
+                                " score contains at least one illegal move ",
+                                "in PGN.\n\nPlease re-confirm request to ",
+                                "insert ",
                             )
                         ),
                         ".",
                     )
                 ),
             ):
-                return
+                return None
             updater.value.set_game_source(self.pgn_score_source_name)
         editor = RecordEdit(updater, None)
         editor.set_data_source(datasource, editor.on_data_change)
@@ -232,13 +220,13 @@ class ShowPGN(ShowText, ScorePGN):
         self.mark_partial_positions_to_be_recalculated(datasource=datasource)
         updater.key.recno = None
         editor.put()
-        tags = updater.value.collected_game._tags
+        tags = updater.value.collected_game.pgn_tags
         tkinter.messagebox.showinfo(
             parent=self.ui.get_toplevel(),
             title=title,
             message="".join(
                 (
-                    mt.title(),
+                    psn.title(),
                     ' "',
                     "  ".join([tags.get(k, "") for k in self.pgn_score_tags]),
                     '" added to database.',
@@ -249,28 +237,18 @@ class ShowPGN(ShowText, ScorePGN):
 
 
 class DisplayPGN(DisplayText):
+    """Provide method to delete an item from database."""
 
-    """Mixin providing methods shared by the gamedisplay.GameDisplay
-    and repertoiredisplay.RepertoireDisplay classes.
-
-    Named DisplayPGN because ShowPGN is already taken, and when created the
-    only methods in the class are delete_game_database and get_database_events.
-    Both were in GameDisplay and RepertoireDisplay originally.
-
-    insert_game_database is in ShowPGN, not here, because it is also used
-    in the InsertPGN line.
-
-    """
-
-    def delete_item_database(self, event=None):
+    def _delete_item_database(self, event=None):
         """Remove PGN score from database on request from item display."""
+        del event
         title = " ".join(("Delete", self.pgn_score_name.title()))
-        mt = self.pgn_score_name
+        psn = self.pgn_score_name
         if self.ui.database is None:
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
                 title=title,
-                message=mt.join(("Cannot delete ", ":\n\nNo database open.")),
+                message=psn.join(("Cannot delete ", ":\n\nNo database open.")),
             )
             return
         datasource = self.ui_base_table.get_data_source()
@@ -278,20 +256,20 @@ class DisplayPGN(DisplayText):
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
                 title=title,
-                message=mt.join(("Cannot delete ", ":\n\n", " list hidden.")),
+                message=psn.join(("Cannot delete ", ":\n\n", " list hidden.")),
             )
             return
         if self.sourceobject is None:
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
                 title=title,
-                message=mt.join(
+                message=psn.join(
                     (
                         "Cannot delete ",
                         "".join(
                             (
-                                ":\n\nDatabase has been closed since this copy ",
-                                "displayed.",
+                                ":\n\nDatabase has been closed since ",
+                                "this copy displayed.",
                             )
                         ),
                     )
@@ -302,10 +280,15 @@ class DisplayPGN(DisplayText):
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
                 title=title,
-                message=mt.join(
+                message=psn.join(
                     (
                         "Cannot delete ",
-                        ":\n\nRecord has been amended since this copy displayed.",
+                        "".join(
+                            (
+                                ":\n\nRecord has been amended since ",
+                                "this copy displayed.",
+                            )
+                        ),
                     )
                 ),
             )
@@ -313,7 +296,7 @@ class DisplayPGN(DisplayText):
         if tkinter.messagebox.YES != tkinter.messagebox.askquestion(
             parent=self.ui.get_toplevel(),
             title=title,
-            message=mt.join(("Confirm request to delete ", " from database")),
+            message=psn.join(("Confirm request to delete ", " from database")),
         ):
             return
         original = self.pgn_score_updater()
@@ -325,13 +308,13 @@ class DisplayPGN(DisplayText):
         editor.set_data_source(datasource, editor.on_data_change)
         self.mark_partial_positions_to_be_recalculated(datasource=datasource)
         editor.delete()
-        tags = original.value.collected_game._tags
+        tags = original.value.collected_game.pgn_tags
         tkinter.messagebox.showinfo(
             parent=self.ui.get_toplevel(),
             title=title,
             message="".join(
                 (
-                    mt.title(),
+                    psn.title(),
                     ' "',
                     "  ".join([tags.get(k, "") for k in self.pgn_score_tags]),
                     '" deleted from database.',
@@ -341,14 +324,7 @@ class DisplayPGN(DisplayText):
 
 
 class InsertPGN(InsertText):
-
-    """Mixin providing methods shared by the gamedisplay.GameDisplayInsert
-    and repertoiredisplay.RepertoireDisplayInsert classes.
-
-    Provide methods involved in generating popup menus relevant to PGN score
-    editing when inserting records.
-
-    """
+    """Provide methods to generate popup menus for inserting PGN scores."""
 
     # The methods identical except for docstrings.  Here 'PGN score' replaces
     # 'game' and 'repertoire'.  The method names already had 'item' rather
@@ -356,93 +332,94 @@ class InsertPGN(InsertText):
     # sometimes the method name should be compatible with the 'CQL' and
     # 'Select' classes.
 
-    def create_primary_activity_popup(self):
-        popup = super().create_primary_activity_popup()
-        self.add_pgn_navigation_to_submenu_of_popup(
+    def _create_primary_activity_popup(self):
+        """Delegate then set bindings for navigation and insert PGN."""
+        popup = super()._create_primary_activity_popup()
+        self._add_pgn_navigation_to_submenu_of_popup(
             popup, index=self.analyse_popup_label
         )
-        self.add_pgn_insert_to_submenu_of_popup(
+        self._add_pgn_insert_to_submenu_of_popup(
             popup,
             include_ooo=True,
             include_move_rav=True,
             index=self.analyse_popup_label,
         )
-        self.add_close_item_entry_to_popup(popup)
+        self._add_close_item_entry_to_popup(popup)
         return popup
 
-    def create_select_move_popup(self):
-        popup = super().create_select_move_popup()
-        self.add_close_item_entry_to_popup(popup)
+    def _create_select_move_popup(self):
+        """Delegate then set bindings for close item."""
+        popup = super()._create_select_move_popup()
+        self._add_close_item_entry_to_popup(popup)
         return popup
 
-    def create_pgn_tag_popup(self):
-        popup = super().create_pgn_tag_popup()
-        self.add_close_item_entry_to_popup(popup)
+    def _create_pgn_tag_popup(self):
+        """Delegate then set bindings for close item."""
+        popup = super()._create_pgn_tag_popup()
+        self._add_close_item_entry_to_popup(popup)
         return popup
 
-    def create_comment_popup(self):
-        popup = super().create_comment_popup()
-        self.add_close_item_entry_to_popup(popup)
+    def _create_comment_popup(self):
+        """Delegate then set bindings for close item."""
+        popup = super()._create_comment_popup()
+        self._add_close_item_entry_to_popup(popup)
         return popup
 
-    def create_nag_popup(self):
-        popup = super().create_nag_popup()
-        self.add_close_item_entry_to_popup(popup)
+    def _create_nag_popup(self):
+        """Delegate then set bindings for close item."""
+        popup = super()._create_nag_popup()
+        self._add_close_item_entry_to_popup(popup)
         return popup
 
-    def create_start_rav_popup(self):
-        popup = super().create_start_rav_popup()
-        self.add_close_item_entry_to_popup(popup)
+    def _create_start_rav_popup(self):
+        """Delegate then set bindings for close item."""
+        popup = super()._create_start_rav_popup()
+        self._add_close_item_entry_to_popup(popup)
         return popup
 
-    def create_end_rav_popup(self):
-        popup = super().create_end_rav_popup()
-        self.add_close_item_entry_to_popup(popup)
+    def _create_end_rav_popup(self):
+        """Delegate then set bindings for close item."""
+        popup = super()._create_end_rav_popup()
+        self._add_close_item_entry_to_popup(popup)
         return popup
 
-    def create_comment_to_end_of_line_popup(self):
-        popup = super().create_comment_to_end_of_line_popup()
-        self.add_close_item_entry_to_popup(popup)
+    def _create_comment_to_end_of_line_popup(self):
+        """Delegate then set bindings for close item."""
+        popup = super()._create_comment_to_end_of_line_popup()
+        self._add_close_item_entry_to_popup(popup)
         return popup
 
-    def create_escape_whole_line_popup(self):
-        popup = super().create_escape_whole_line_popup()
-        self.add_close_item_entry_to_popup(popup)
+    def _create_escape_whole_line_popup(self):
+        """Delegate then set bindings for close item."""
+        popup = super()._create_escape_whole_line_popup()
+        self._add_close_item_entry_to_popup(popup)
         return popup
 
-    def create_reserved_popup(self):
-        popup = super().create_reserved_popup()
-        self.add_close_item_entry_to_popup(popup)
+    def _create_reserved_popup(self):
+        """Delegate then set bindings for close item."""
+        popup = super()._create_reserved_popup()
+        self._add_close_item_entry_to_popup(popup)
         return popup
 
-    def set_edit_symbol_mode_bindings(self, switch=True, **ka):
-        """Delegate to toggle other relevant bindings and toggle bindings for
-        database actions, navigation to other widgets, and close widget.
-
-        """
-        super().set_edit_symbol_mode_bindings(switch=switch, **ka)
-        self.set_database_navigation_close_item_bindings(switch=switch)
+    def _set_edit_symbol_mode_bindings(self, switch=True, **ka):
+        """Delegate then set bindings for navigation and close item."""
+        super()._set_edit_symbol_mode_bindings(switch=switch, **ka)
+        self._set_database_navigation_close_item_bindings(switch=switch)
 
 
 class EditPGN(EditText):
+    """Provide methods to generate popup menus for editing PGN scores."""
 
-    """Mixin providing methods shared by the gamedisplay.GameDisplayEdit
-    and repertoiredisplay.RepertoireDisplayEdit classes.
-
-    Provide methods involved in generating popup menus relevant to PGN score
-    editing when editing records.
-
-    """
-
-    def update_item_database(self, event=None):
+    def _update_item_database(self, event=None):
         """Modify existing PGN score record."""
+        del event
         title = " ".join(("Edit", self.pgn_score_name.title()))
-        mt = self.pgn_score_name
+        psn = self.pgn_score_name
         if self.ui.database is None:
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
                 title=title,
-                message=mt.join(("Cannot edit ", ":\n\nNo database open.")),
+                message=psn.join(("Cannot edit ", ":\n\nNo database open.")),
             )
             return
         datasource = self.ui_base_table.get_data_source()
@@ -450,20 +427,20 @@ class EditPGN(EditText):
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
                 title=title,
-                message=mt.join(("Cannot edit ", ":\n\n", " list hidden.")),
+                message=psn.join(("Cannot edit ", ":\n\n", " list hidden.")),
             )
             return
         if self.sourceobject is None:
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
                 title=title,
-                message=mt.join(
+                message=psn.join(
                     (
                         "Cannot edit ",
                         "".join(
                             (
-                                ":\n\nDatabase has been closed since this copy ",
-                                "displayed.",
+                                ":\n\nDatabase has been closed since ",
+                                "this copy displayed.",
                             )
                         ),
                     )
@@ -474,10 +451,15 @@ class EditPGN(EditText):
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
                 title=title,
-                message=mt.join(
+                message=psn.join(
                     (
                         "Cannot edit ",
-                        ":\n\nRecord has been amended since this copy displayed.",
+                        "".join(
+                            (
+                                ":\n\nRecord has been amended since ",
+                                "this copy displayed.",
+                            )
+                        ),
                     )
                 ),
             )
@@ -485,7 +467,7 @@ class EditPGN(EditText):
         if tkinter.messagebox.YES != tkinter.messagebox.askquestion(
             parent=self.ui.get_toplevel(),
             title=title,
-            message=mt.join(("Confirm request to edit ", ".")),
+            message=psn.join(("Confirm request to edit ", ".")),
         ):
             return
         original = self.pgn_score_updater()
@@ -498,7 +480,7 @@ class EditPGN(EditText):
         # Then original would not be used. Instead DataSource.new_row
         # gets record keyed by sourceobject and update is used to edit this.
         text = self.get_score_error_escapes_removed()
-        updater = self.game_updater(repr(text))
+        updater = self._game_updater(repr(text))
         editor = RecordEdit(updater, original)
         editor.set_data_source(datasource, editor.on_data_change)
         updater.set_database(editor.get_data_source().dbhome)
@@ -506,13 +488,14 @@ class EditPGN(EditText):
             if tkinter.messagebox.YES != tkinter.messagebox.askquestion(
                 parent=self.ui.get_toplevel(),
                 title=title,
-                message=mt.join(
+                message=psn.join(
                     (
                         "The edited ",
                         "".join(
                             (
-                                " score contains at least one illegal move in ",
-                                "PGN.\n\nPlease re-confirm request to edit ",
+                                " score contains at least one illegal move ",
+                                "in PGN.\n\nPlease re-confirm request to ",
+                                "edit ",
                             )
                         ),
                         ".",
@@ -528,14 +511,14 @@ class EditPGN(EditText):
         if self is self.ui_displayed_items.active_item:
             newkey = self.ui_displayed_items.adjust_edited_item(updater)
             if newkey:
-                self.set_properties_on_grids(newkey)
-        tags = original.value.collected_game._tags
+                self._set_properties_on_grids(newkey)
+        tags = original.value.collected_game.pgn_tags
         tkinter.messagebox.showinfo(
             parent=self.ui.get_toplevel(),
             title=title,
             message="".join(
                 (
-                    mt.title(),
+                    psn.title(),
                     ' "',
                     "  ".join([tags.get(k, "") for k in self.pgn_score_tags]),
                     '" amended on database.',
