@@ -2,8 +2,7 @@
 # Copyright 2009 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Make and copy chess pieces fonts for ChessTab.
-"""
+"""Make and copy chess pieces fonts for ChessTab."""
 
 import tkinter
 import tkinter.font
@@ -22,15 +21,15 @@ import tkinter.font
 # unix-like systems.
 import multiprocessing
 
+from . import constants
+
 try:
     multiprocessing.Queue()
-    _assume_wine = False
+    _ASSUME_WINE = False
 except OSError:
-    _assume_wine = True
+    _ASSUME_WINE = True
 del multiprocessing
 
-from . import constants
-
 modify_font_attributes = ("family", "weight", "slant", "size")
 modify_board_font_attributes = ("family", "weight")
 integer_attributes = {"size"}
@@ -64,14 +63,14 @@ def make_chess_fonts(root, preferred_pieces=constants.PREFERRED_PIECES):
         root=root, name=constants.WILDPIECES_ON_BOARD_FONT, **default
     )
 
-    ff = set(tkinter.font.families())
-    for pff in preferred_pieces:
-        if pff in ff:
+    font_families = set(tkinter.font.families())
+    for preference in preferred_pieces:
+        if preference in font_families:
             del default["family"]
             pieces = tkinter.font.Font(
                 root=root,
                 name=constants.PIECES_ON_BOARD_FONT,
-                family=pff,
+                family=preference,
                 **default
             )
             break
@@ -96,14 +95,14 @@ def make_list_fonts(root):
 
 def _copy_font_attributes(attributes, source, target):
     """Copy attributes from source font to target font."""
-    for fa in attributes:
-        if fa in source:
-            target[fa] = source[fa]
+    for attr in attributes:
+        if attr in source:
+            target[attr] = source[attr]
 
 
 def _get_default_font_actual(widget_class):
     """Return actuals for widget_class font or Courier if it does not exist."""
-    if _assume_wine:
+    if _ASSUME_WINE:
         return tkinter.font.Font(family="Courier").actual()
 
     # On MS Windows the named font from widget_class exists at Python2.6
