@@ -42,7 +42,8 @@ from ..core.pgn import (
     GameAnalysis,
 )
 from .board import Board
-from .score import Score, AnalysisScore, ScoreNoGameException
+from .score import Score, ScoreNoGameException
+from .analysisscore import AnalysisScore
 from .constants import (
     ANALYSIS_INDENT_TAG,
     ANALYSIS_PGN_TAGS_TAG,
@@ -51,6 +52,7 @@ from .constants import (
     MOVETEXT_MOVENUMBER_TAG,
     STATUS_SEVEN_TAG_ROSTER_PLAYERS,
 )
+from .blanktext import NonTagBind
 from .eventspec import EventSpec
 from ..core.analysis import Analysis
 from ..core.constants import (
@@ -58,9 +60,10 @@ from ..core.constants import (
     END_TAG,
     START_TAG,
 )
+from .eventbinding import EventBinding, AnalysisEventBinding
 
 
-class Game(Score):
+class Game(Score, EventBinding, AnalysisEventBinding):
     """Chess game widget composed from Board and Text widgets.
 
     master is used as the master argument for the tkinter Frame widget passed
@@ -116,8 +119,9 @@ class Game(Score):
     ):
         """Create Frame and Board, then delegate, then set grid geometry."""
         self.ui = ui
-        panel = tkinter.Frame(master, borderwidth=2, relief=tkinter.RIDGE)
-        panel.bind("<Configure>", self.try_event(self._on_configure))
+        panel = tkinter.Frame(
+            master=master, cnf=dict(borderwidth=2, relief=tkinter.RIDGE)
+        )
         panel.grid_propagate(False)
         board = Board(panel, boardfont=boardfont, ui=ui)
         super().__init__(
@@ -131,6 +135,11 @@ class Game(Score):
             **ka
         )
         self.scrollbar.grid(column=2, row=0, rowspan=1, sticky=tkinter.NSEW)
+        self.bind(
+            panel,
+            "<Configure>",
+            function=self.try_event(self._on_configure_initial),
+        )
         self.analysis = AnalysisScore(
             panel,
             board,
@@ -164,18 +173,30 @@ class Game(Score):
             panel.after_idle(self.hide_game_analysis)
         if not ui.visible_scrollbars:
             panel.after_idle(self.hide_scrollbars)
-        self.configure_game_widget()
+        self._configure_game_widget()
 
         # True means analysis widget refers to same position as game widget; so
         # highlighting of analysis still represents future valid navigation.
         # Any navigation in game widget makes any highlighting in analysis
         # widget out of date.
-        self.game_position_analysis = False
+        # Defining properties, or direct access, leads to pylint messages
+        # attribute-defined-outside-init and access-member-before-definition
+        # in scorepgn.ScorePGN.analysis_current_item method.
+        # Explicit get and set methods are accepted without pylint messages.
+        self._game_position_analysis = False
 
         self.game_analysis_in_progress = False
         self.takefocus_widget = self.score
         self.analysis_data_source = None
 
+    def _get_game_position_analysis(self):
+        """Return number of leading spaces."""
+        return self._game_position_analysis
+
+    def _set_game_position_analysis(self, value):
+        """Set self._game_position_analysis to value."""
+        self._game_position_analysis = value
+
     def get_top_widget(self):
         """Return topmost widget for game display."""
         return self.panel
@@ -204,23 +225,29 @@ class Game(Score):
         )
         self.panel.destroy()
 
-    def _on_configure(self, event=None):
-        """Catch initial configure and rebind to on_configure."""
+    def _on_configure_initial(self, event=None):
+        """Catch initial configure and rebind to _on_configure."""
         # Not sure, at time of writing this, how partial.py is
         # different but that module does not need this trick to display
         # the control with the right size on creation.
         # Here extra first event has width=1 height=1 followed up by event
         # with required dimensions.
-        self.panel.bind("<Configure>", self.try_event(self.on_configure))
+        del event
+        self.bind(
+            self.panel,
+            "<Configure>",
+            function=self.try_event(self._on_configure),
+        )
 
-    def on_configure(self, event=None):
+    def _on_configure(self, event=None):
         """Reconfigure board and score after container has been resized."""
-        self.configure_game_widget()
-        self.see_current_move()
+        del event
+        self._configure_game_widget()
+        self._see_current_move()
 
     def _analyse_position(self, *position):
         analysis = self.get_analysis(*position)
-        self.refresh_analysis_widget_from_database(analysis)
+        self._refresh_analysis_widget_from_database(analysis)
         if self.game_analysis_in_progress:
             if not self.ui.uci.uci.is_positions_pending_empty():
                 return
@@ -250,7 +277,7 @@ class Game(Score):
         # Assume setting new position implies analysis is out of date.
         # Caller should reset to True if sure analysis still refers to game
         # position. (Probably just F7 or F8 to the game widget.)
-        self.game_position_analysis = False
+        self._game_position_analysis = False
 
         if not super().set_game_board():
             return
@@ -261,15 +288,57 @@ class Game(Score):
         self._analyse_position(*position)
 
     def set_and_tag_item_text(self, reset_undo=False):
-        """Delegate then queue analysis request to chess engines."""
+        """Display the game as board and moves.
+
+        reset_undo causes the undo redo stack to be cleared if True.  Set True
+        on first display of a game for editing so that repeated Ctrl-Z in text
+        editing mode recovers the original score.
+
+        """
+        if not self._is_text_editable:
+            self.score.configure(state=tkinter.NORMAL)
+        self.score.delete("1.0", tkinter.END)
         try:
-            super().set_and_tag_item_text(reset_undo=reset_undo)
+            self.map_game()
         except ScoreNoGameException:
+            self.score.insert(
+                tkinter.END,
+                "".join(
+                    (
+                        "The following text was probably found between two ",
+                        "games in a file expected to be in PGN format.\n\n",
+                    )
+                ),
+            )
+            self.score.insert(tkinter.END, self.collected_game.pgn_text)
+
+            # Must be replaced because _bind_for_primary_activity() sets the
+            # board pointer bindings wrong for initial display of game.
+            if self._most_recent_bindings != NonTagBind.NO_EDITABLE_TAGS:
+                self._bind_for_primary_activity()
+                self._set_board_pointer_widget_navigation_bindings(True)
+
+            if not self._is_text_editable:
+                self.score.configure(state=tkinter.DISABLED)
+            if reset_undo:
+                self.score.edit_reset()
             return
+
+        # Must be replaced because _bind_for_primary_activity() sets the
+        # board pointer bindings wrong for initial display of game.
+        if self._most_recent_bindings != NonTagBind.NO_EDITABLE_TAGS:
+            self._bind_for_primary_activity()
+            self._set_board_pointer_widget_navigation_bindings(True)
+
+        if not self._is_text_editable:
+            self.score.configure(state=tkinter.DISABLED)
+        if reset_undo:
+            self.score.edit_reset()
+        self.board.set_board(self.fen_tag_square_piece_map())
         self.score.tag_add(MOVETEXT_INDENT_TAG, "1.0", tkinter.END)
         self._analyse_position(*self.fen_tag_tuple_square_piece_map())
 
-    def analyse_game(self):
+    def _analyse_game(self):
         """Analyse all positions in game using all active engines."""
         uci = self.ui.uci.uci
         sas = self.analysis.score
@@ -280,7 +349,8 @@ class Game(Score):
             analysis.variations.clear()
 
             # Avoid "OSError: [WinError 535] Pipe connected"  at Python3.3
-            # running under Wine on FreeBSD 10.1 by disabling the UCI functions.
+            # running under Wine on FreeBSD 10.1 by disabling the UCI
+            # functions.
             # Assume all later Pythons are affected because they do not install
             # under Wine at time of writing.
             # The OSError stopped happening by wine-2.0_3,1 on FreeBSD 10.1 but
@@ -289,7 +359,7 @@ class Game(Score):
             # problem is being shifted constructively.
             # At Python3.5 running under Wine on FreeBSD 10.1, get() does not
             # wait when the queue is empty either, and ChessTab does not run
-            # under Python3.3 because it uses asyncio: so no point in disabling.
+            # under Python3.3 because it uses asyncio: so no point disabling.
             # try:
             #    uci.ui_analysis_queue.put((sas, pa))
             # except AttributeError:
@@ -305,8 +375,8 @@ class Game(Score):
         self.score.grid_configure(rowspan=2)
         if self.score.grid_info()["columnspan"] == 1:
             self.scrollbar.grid_configure(rowspan=2)
-        self.configure_game_widget()
-        self.see_current_move()
+        self._configure_game_widget()
+        self._see_current_move()
 
     def show_game_analysis(self):
         """Show the widgets which show analysis from chess engines."""
@@ -317,8 +387,8 @@ class Game(Score):
             self.analysis.scrollbar.grid_configure()
         else:
             self.analysis.score.grid_configure(columnspan=3)
-        self.configure_game_widget()
-        self.see_current_move()
+        self._configure_game_widget()
+        self._see_current_move()
 
     def hide_scrollbars(self):
         """Hide the scrollbars in the game display widgets."""
@@ -327,8 +397,8 @@ class Game(Score):
         self.score.grid_configure(columnspan=2)
         if self.score.grid_info()["rowspan"] == 1:
             self.analysis.score.grid_configure(columnspan=3)
-        self.configure_game_widget()
-        self.see_current_move()
+        self._configure_game_widget()
+        self._see_current_move()
 
     def show_scrollbars(self):
         """Show the scrollbars in the game display widgets."""
@@ -339,8 +409,8 @@ class Game(Score):
             self.analysis.scrollbar.grid_configure()
         else:
             self.scrollbar.grid_configure(rowspan=2)
-        self.configure_game_widget()
-        self.see_current_move()
+        self._configure_game_widget()
+        self._see_current_move()
 
     def toggle_analysis_fen(self):
         """Toggle display of FEN in analysis widgets."""
@@ -349,7 +419,7 @@ class Game(Score):
             widget.tag_configure(ANALYSIS_PGN_TAGS_TAG, elide=tkinter.FALSE)
         else:
             widget.tag_configure(ANALYSIS_PGN_TAGS_TAG, elide=tkinter.TRUE)
-        self.see_current_move()
+        self._see_current_move()
 
     def toggle_game_move_numbers(self):
         """Toggle display of move numbers in game score widgets."""
@@ -358,12 +428,12 @@ class Game(Score):
             widget.tag_configure(MOVETEXT_MOVENUMBER_TAG, elide=tkinter.FALSE)
         else:
             widget.tag_configure(MOVETEXT_MOVENUMBER_TAG, elide=tkinter.TRUE)
-        self.see_current_move()
+        self._see_current_move()
 
-    def refresh_analysis_widget_from_engine(self, analysis):
+    def _refresh_analysis_widget_from_engine(self, analysis):
         """Refresh game widget with updated chess engine analysis."""
         uci = self.ui.uci.uci
-        move_played = self.get_move_for_start_of_analysis()
+        move_played = self._get_move_for_start_of_analysis()
         if analysis.position in uci.position_analysis:
             new_text = uci.position_analysis[
                 analysis.position
@@ -418,20 +488,20 @@ class Game(Score):
                 ANALYSIS_PGN_TAGS_TAG, "1.0", widget.tag_ranges(fmog)[0]
             )
 
-    def refresh_analysis_widget_from_database(self, analysis):
+    def _refresh_analysis_widget_from_database(self, analysis):
         """Refresh game widget with updated chess engine analysis."""
         # When a database is open the analysis is refreshed from the database
         # while checking if that analysis is up-to-date compared with the depth
         # and multiPV parameters held in self.uci.uci UCI object.
         if self.ui.database is None:
-            self.refresh_analysis_widget_from_engine(analysis)
+            self._refresh_analysis_widget_from_engine(analysis)
             return
 
         # Assume TypeError exception happens because analysis is being shown
         # for a position which is checkmate or stalemate.
         try:
             new_text = analysis.translate_analysis_to_pgn(
-                self.get_move_for_start_of_analysis()
+                self._get_move_for_start_of_analysis()
             )
         except TypeError:
             return
@@ -468,9 +538,9 @@ class Game(Score):
         # This method called at regular intervals to cope with fresh analysis
         # of displayed positions due to changes in engine parameters (depth
         # and multiPV). Need a set of new analysis since last call.
-        self.refresh_analysis_widget_from_database(analysis)
+        self._refresh_analysis_widget_from_database(analysis)
 
-    def configure_game_widget(self):
+    def _configure_game_widget(self):
         """Configure board and score widgets for a game display."""
         width = self.panel.winfo_width()
         height = self.panel.winfo_height()
@@ -496,17 +566,17 @@ class Game(Score):
         self.panel.grid_columnconfigure(1, weight=1)
         self.panel.grid_columnconfigure(2, weight=0)
 
-    def set_primary_activity_bindings(self, switch=True):
+    def _set_primary_activity_bindings(self, switch=True):
         """Delegate then set board pointer move navigation bindings."""
-        super().set_primary_activity_bindings(switch=switch)
+        super()._set_primary_activity_bindings(switch=switch)
         if self.score is self.takefocus_widget:
             self.set_board_pointer_move_bindings(switch=switch)
         else:
             self.analysis.set_board_pointer_move_bindings(switch=switch)
 
-    def set_select_variation_bindings(self, switch=True):
+    def _set_select_variation_bindings(self, switch=True):
         """Delegate then set board pointer select variation bindings."""
-        super().set_select_variation_bindings(switch=switch)
+        super()._set_select_variation_bindings(switch=switch)
         if self.score is self.takefocus_widget:
             self.set_board_pointer_select_variation_bindings(switch=switch)
         else:
@@ -519,27 +589,17 @@ class Game(Score):
     # is to leave Database and Close Item bindings out of self.analysis.
     # Database and Close Item refer to the item, game or repertoire, not the
     # engine analysis.
-    def set_database_navigation_close_item_bindings(self, switch=True):
+    def _set_database_navigation_close_item_bindings(self, switch=True):
         """Enable or disable bindings for navigation and database selection."""
-        self.set_event_bindings_score(
-            self.get_database_events(), switch=switch
-        )
-        self.set_event_bindings_score(
-            self.get_navigation_events(), switch=switch
-        )
-        self.set_event_bindings_score(
-            self.get_close_item_events(), switch=switch
-        )
-        self.analysis.set_event_bindings_score(
-            self.get_navigation_events(), switch=switch
-        )
+        super()._set_database_navigation_close_item_bindings(switch=switch)
+        self._set_analysis_event_bindings_score(switch=switch)
 
-    def set_board_pointer_widget_navigation_bindings(self, switch):
+    def _set_board_pointer_widget_navigation_bindings(self, switch):
         """Enable or disable bindings for widget selection."""
-        self.set_event_bindings_board(
-            self.get_modifier_buttonpress_suppression_events(), switch=switch
+        self._set_event_bindings_board(
+            self._get_modifier_buttonpress_suppression_events(), switch=switch
         )
-        self.set_event_bindings_board(
+        self._set_event_bindings_board(
             (
                 (EventSpec.buttonpress_1, self.give_focus_to_widget),
                 (EventSpec.buttonpress_3, self.post_inactive_menu),
@@ -549,8 +609,8 @@ class Game(Score):
 
     def set_score_pointer_widget_navigation_bindings(self, switch):
         """Set or unset pointer bindings for widget navigation."""
-        self.set_event_bindings_board(
-            self.get_modifier_buttonpress_suppression_events(), switch=switch
+        self._set_event_bindings_board(
+            self._get_modifier_buttonpress_suppression_events(), switch=switch
         )
         if not switch:
             bindings = (
@@ -570,28 +630,6 @@ class Game(Score):
                 ((EventSpec.buttonpress_3, self.analysis.post_inactive_menu),)
             )
 
-    def set_toggle_game_analysis_bindings(self, switch):
-        """Set keystoke bindings to switch between game and analysis."""
-        self.set_event_bindings_score(
-            ((EventSpec.scoresheet_to_analysis, self.analysis_current_item),)
-        )
-        self.analysis.set_event_bindings_score(
-            ((EventSpec.analysis_to_scoresheet, self.current_item),)
-        )
-
-    def set_score_pointer_to_score_bindings(self, switch):
-        """Set score pointer bindings to go to game."""
-        self.set_event_bindings_score(
-            ((EventSpec.alt_buttonpress_1, self.current_item),), switch=switch
-        )
-
-    def set_analysis_score_pointer_to_analysis_score_bindings(self, switch):
-        """Set analysis score pointer bindings to go to analysis score."""
-        self.analysis.set_event_bindings_score(
-            ((EventSpec.alt_buttonpress_1, self.analysis_current_item),),
-            switch=switch,
-        )
-
     def set_colours(self, sbg, bbg, bfg):
         """Set colours and fonts used to display games.
 
@@ -632,17 +670,20 @@ class Game(Score):
         """Return database analysis for position or empty position Analysis.
 
         get_analysis is not interested in the arguments, which are passed on
-        to self.generate_fen_for_position().
+        to self._generate_fen_for_position().
 
         """
+        # pylint message no-value-for-parameter seems to be false positive.
+        # See similar code in gameedit_misc.create_edit_move_context method
+        # which does not attract the message.
         if self.analysis_data_source:
             return self.analysis_data_source.get_position_analysis(
-                self.generate_fen_for_position(*a)
+                self._generate_fen_for_position(*a)
             )
-        return Analysis(position=self.generate_fen_for_position(*a))
+        return Analysis(position=self._generate_fen_for_position(*a))
 
     @staticmethod
-    def generate_fen_for_position(squares, *a):
+    def _generate_fen_for_position(squares, *a):
         """Return FEN for current position.
 
         Ensure the Piece instances in the squares dictionary reference their
@@ -657,26 +698,26 @@ class Game(Score):
             piece.set_square(square)
         return generate_fen_for_position(squares.values(), *a)
 
-    def create_primary_activity_popup(self):
+    def _create_primary_activity_popup(self):
         """Delegate then add navigation submenu and return popup menu."""
-        popup = super().create_primary_activity_popup()
-        self.set_popup_bindings(
+        popup = super()._create_primary_activity_popup()
+        self._set_popup_bindings(
             popup,
-            ((EventSpec.analyse_game, self.analyse_game),),
+            ((EventSpec.analyse_game, self._analyse_game),),
             index=self.export_popup_label,
         )
-        self.create_widget_navigation_submenu_for_popup(popup)
+        self._create_widget_navigation_submenu_for_popup(popup)
         return popup
 
-    def create_select_move_popup(self):
+    def _create_select_move_popup(self):
         """Delegate then add navigation submenu and return popup menu."""
-        popup = super().create_select_move_popup()
-        self.create_widget_navigation_submenu_for_popup(popup)
+        popup = super()._create_select_move_popup()
+        self._create_widget_navigation_submenu_for_popup(popup)
         return popup
 
     def set_statusbar_text(self):
         """Set status bar to display player name PGN Tags."""
-        tags = self.collected_game._tags
+        tags = self.collected_game.pgn_tags
         self.ui.statusbar.set_status_text(
             "  ".join(
                 [tags.get(k, "") for k in STATUS_SEVEN_TAG_ROSTER_PLAYERS]
