@@ -2,26 +2,19 @@
 # Copyright 2008 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Customise edit toplevel to edit or insert chess game record.
-"""
-
-import tkinter
-import tkinter.messagebox
+"""Customise edit toplevel to edit or insert chess game record."""
 
 from solentware_grid.gui.dataedit import DataEdit
 
-from solentware_misc.gui.exceptionhandler import ExceptionHandler
-
 from pgn_read.core.parser import PGN
 from pgn_read.core.constants import TAG_WHITE, TAG_BLACK
 
 from .gametoplevel import GameToplevel, GameToplevelEdit
-from .toplevelpgn import EditPGN
+from .toplevelpgn import EditPGNToplevel
 from .constants import EMPTY_SEVEN_TAG_ROSTER
 
 
-class GameDbEdit(ExceptionHandler, EditPGN, DataEdit):
-
+class GameDbEdit(EditPGNToplevel, DataEdit):
     """Edit PGN text for game on database, or insert a new record.
 
     parent is used as the master argument in GameToplevel calls.
@@ -43,7 +36,7 @@ class GameDbEdit(ExceptionHandler, EditPGN, DataEdit):
     Attribute pgn_score_source provides the error key value to index a PGN
     game score with errors.
 
-    Methods get_title_for_object and set_item, and properties ui_base_table;
+    Methods _get_title_for_object and _set_item, and properties ui_base_table;
     ui_items_in_toplevels; and ui, allow similar methods in various classes
     to be expressed identically and defined once.
 
@@ -54,44 +47,53 @@ class GameDbEdit(ExceptionHandler, EditPGN, DataEdit):
     pgn_score_source = "Editor"
 
     def __init__(
-        self, newobject, parent, oldobject, showinitial=True, ui=None
+        self,
+        newobject=None,
+        parent=None,
+        oldobject=None,
+        showinitial=True,
+        ui=None,
     ):
         """Extend and create dialogue widget to edit or insert chess game."""
         if not oldobject:
             showinitial = False
         super().__init__(
-            newobject,
-            parent,
-            oldobject,
-            GameToplevelEdit(master=parent, ui=ui),
-            "",
+            newobject=newobject,
+            parent=parent,
+            oldobject=oldobject,
+            newview=GameToplevelEdit(master=parent, ui=ui),
+            title="",
             oldview=GameToplevel(master=parent, ui=ui)
             if showinitial
             else showinitial,
         )
-        self.initialize()
+        self._initialize()
 
     @property
     def ui_base_table(self):
+        """Return the User Interface TagRosterGrid object."""
         return self.ui.base_games
 
     @property
     def ui_items_in_toplevels(self):
+        """Return the User Interface objects in Toplevels."""
         return self.ui.games_and_repertoires_in_toplevels
 
     @property
     def ui(self):
+        """Return the User Interface object from 'editable' view."""
         return self.newview.ui
 
-    def set_item(self, view, object_):
-        self.set_default_source_for_object(object_)
+    def _set_item(self, view, object_):
+        """Populate view with the game extracted from object_."""
+        self._set_default_source_for_object(object_)
         view.set_position_analysis_data_source()
         view.collected_game = next(
             PGN(game_class=view.gameclass).read_games(object_.get_srvalue())
         )
         view.set_and_tag_item_text()
 
-    def get_title_for_object(self, object_=None):
+    def _get_title_for_object(self, object_=None):
         """Return title for Toplevel containing a Game object_.
 
         Default value of object_ is oldobject attribute from DataEdit class.
@@ -100,7 +102,7 @@ class GameDbEdit(ExceptionHandler, EditPGN, DataEdit):
         if object_ is None:
             object_ = self.oldobject
         if object_:
-            tags = object_.value.collected_game._tags
+            tags = object_.value.collected_game.pgn_tags
             try:
                 return "  ".join(
                     (
@@ -119,7 +121,7 @@ class GameDbEdit(ExceptionHandler, EditPGN, DataEdit):
         else:
             return "".join(("Insert ", self.pgn_score_name))
 
-    def set_default_source_for_object(self, object_=None):
+    def _set_default_source_for_object(self, object_=None):
         """Set default source for Toplevel containing a Game object_.
 
         Default value of object_ is oldobject attribute from DataEdit class.
@@ -130,14 +132,21 @@ class GameDbEdit(ExceptionHandler, EditPGN, DataEdit):
         Now present for compatibility with Repertoires.
 
         """
-        pass
 
-    def put(self):
+    # Resolve pylint message arguments-differ deferred.
+    # Depends on detail of planned naming of methods as private if possible.
+    # mark...recalculated starts and commits a transaction unconditionally.
+    # No harm in using the same default as the 'super()' method.
+    def put(self, commit=True):
         """Mark partial position records for recalculation and return key."""
         self.datasource.dbhome.mark_partial_positions_to_be_recalculated()
-        super().put()
+        super().put(commit=commit)
 
-    def edit(self):
+    # Resolve pylint message arguments-differ deferred.
+    # Depends on detail of planned naming of methods as private if possible.
+    # mark...recalculated starts and commits a transaction unconditionally.
+    # No harm in using the same default as the 'super()' method.
+    def edit(self, commit=True):
         """Mark partial position records for recalculation and return key."""
         self.datasource.dbhome.mark_partial_positions_to_be_recalculated()
-        super().edit()
+        super().edit(commit=commit)
