@@ -2,23 +2,19 @@
 # Copyright 2008 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Customise show toplevel to display chess game record.
-"""
+"""Customise show toplevel to display chess game record."""
 
 from solentware_grid.gui.datashow import DataShow
 
-from solentware_misc.gui.exceptionhandler import ExceptionHandler
-
 from pgn_read.core.parser import PGN
 
 from pgn_read.core.constants import TAG_WHITE, TAG_BLACK
 
 from .gametoplevel import GameToplevel
-from .toplevelpgn import ShowPGN
+from .toplevelpgn import ShowPGNToplevel
 
 
-class GameDbShow(ExceptionHandler, ShowPGN, DataShow):
-
+class GameDbShow(ShowPGNToplevel, DataShow):
     """Show PGN text for game from database.
 
     parent is used as the master argument in a GameToplevel call.
@@ -31,7 +27,7 @@ class GameDbShow(ExceptionHandler, ShowPGN, DataShow):
     Attribute pgn_score_name provides the name used in widget titles and
     message text.
 
-    Methods get_title_for_object and set_item, and properties ui_base_table;
+    Methods _get_title_for_object and _set_item, and properties ui_base_table;
     ui_items_in_toplevels; and ui, allow similar methods in various classes
     to be expressed identically and defined once.
 
@@ -39,35 +35,42 @@ class GameDbShow(ExceptionHandler, ShowPGN, DataShow):
 
     pgn_score_name = "Game"
 
-    def __init__(self, parent, oldobject, ui=None):
+    def __init__(self, parent=None, oldobject=None, ui=None):
         """Extend and create toplevel widget for displaying chess game."""
-        # Toplevel title set '' in __init__ and to proper value in initialize.
+        # Toplevel title set '' in __init__ and to proper value in _initialize.
         super().__init__(
-            oldobject, parent, GameToplevel(master=parent, ui=ui), ""
+            instance=oldobject,
+            parent=parent,
+            oldview=GameToplevel(master=parent, ui=ui),
+            title="",
         )
-        self.initialize()
+        self._initialize()
 
     @property
     def ui_base_table(self):
+        """Return the User Interface TagRosterGrid object."""
         return self.ui.base_games
 
     @property
     def ui_items_in_toplevels(self):
+        """Return the User Interface objects in Toplevels."""
         return self.ui.games_and_repertoires_in_toplevels
 
     @property
     def ui(self):
+        """Return the User Interface object from 'read-only' view."""
         return self.oldview.ui
 
-    def set_item(self, view, object_):
-        self.set_default_source_for_object(object_)
+    def _set_item(self, view, object_):
+        """Populate view with the game extracted from object_."""
+        self._set_default_source_for_object(object_)
         view.set_position_analysis_data_source()
         view.collected_game = next(
             PGN(game_class=view.gameclass).read_games(object_.get_srvalue())
         )
         view.set_and_tag_item_text()
 
-    def get_title_for_object(self, object_=None):
+    def _get_title_for_object(self, object_=None):
         """Return title for Toplevel containing a Game object_.
 
         Default value of object_ is object attribute from DataShow class.
@@ -76,7 +79,7 @@ class GameDbShow(ExceptionHandler, ShowPGN, DataShow):
         if object_ is None:
             object_ = self.object
         try:
-            tags = object_.value.collected_game._tags
+            tags = object_.value.collected_game.pgn_tags
             return "  ".join(
                 (
                     self.pgn_score_name.join(("Show ", ":")),
@@ -92,7 +95,7 @@ class GameDbShow(ExceptionHandler, ShowPGN, DataShow):
                 ("Show ", " - names unknown or invalid")
             )
 
-    def set_default_source_for_object(self, object_=None):
+    def _set_default_source_for_object(self, object_=None):
         """Set default source for Toplevel containing a Game object_.
 
         Default value of object_ is object attribute from DataShow class.
@@ -103,4 +106,3 @@ class GameDbShow(ExceptionHandler, ShowPGN, DataShow):
         Now present for compatibility with Repertoires.
 
         """
-        pass
