@@ -21,7 +21,7 @@ main display (that includes widgets displaying text).
 
 from solentware_grid.core.dataclient import DataNotify
 
-from solentware_misc.gui.exceptionhandler import ExceptionHandler
+from solentware_bind.gui.bindings import Bindings
 
 from .game import Game
 from .gameedit import GameEdit
@@ -32,7 +32,7 @@ from .display import Display
 from .displaypgn import ShowPGN, InsertPGN, EditPGN, DisplayPGN
 
 
-class _GameDisplay(ExceptionHandler, Display):
+class _GameDisplay(ShowPGN, DisplayPGN, Game, Display, Bindings, DataNotify):
     """Extend and link PGN game text to database.
 
     sourceobject - link to database.
@@ -101,8 +101,9 @@ class _GameDisplay(ExceptionHandler, Display):
         """Return the displayed games."""
         return self.ui.game_items
 
-    # Defined so cycle_item and give_focus_to_widget methods can be shared by
-    # gamedisplay._GameDisplay and repertoiredisplay._RepertoireDisplay classes.
+    # Defined so _cycle_item and give_focus_to_widget methods can be shared by
+    # gamedisplay._GameDisplay and repertoiredisplay._RepertoireDisplay
+    # classes.
     @property
     def ui_configure_item_list_grid(self):
         """Return method to configure game grid widget."""
@@ -123,11 +124,12 @@ class _GameDisplay(ExceptionHandler, Display):
         """Return game and repertoire items in Toplevels."""
         return self.ui.games_and_repertoires_in_toplevels
 
-    def mark_partial_positions_to_be_recalculated(self, datasource=None):
+    @staticmethod
+    def mark_partial_positions_to_be_recalculated(datasource=None):
         """Mark ChessQL statements, in datasource, to be recalculated."""
         datasource.dbhome.mark_partial_positions_to_be_recalculated()
 
-    def get_navigation_events(self):
+    def _get_navigation_events(self):
         """Return event description tuple for navigation from game."""
         return (
             (
@@ -164,8 +166,8 @@ class _GameDisplay(ExceptionHandler, Display):
                 EventSpec.navigate_to_active_selection_rule,
                 self.set_focus_selectionpanel_item,
             ),
-            (EventSpec.gamedisplay_to_previous_game, self.prior_item),
-            (EventSpec.gamedisplay_to_next_game, self.next_item),
+            (EventSpec.gamedisplay_to_previous_game, self._prior_item),
+            (EventSpec.gamedisplay_to_next_game, self._next_item),
             (EventSpec.tab_traverse_forward, self.traverse_forward),
             (EventSpec.tab_traverse_backward, self.traverse_backward),
             # No traverse_round because Alt-F8 toggles game and analysis.
@@ -173,6 +175,7 @@ class _GameDisplay(ExceptionHandler, Display):
 
     def delete_item_view(self, event=None):
         """Remove game item from screen."""
+        del event
         self.set_data_source()
         self.ui.delete_game_view(self)
 
@@ -185,20 +188,20 @@ class _GameDisplay(ExceptionHandler, Display):
                 and self.datasource.dbset == self.sourceobject.dbset
             ):
                 self.blockchange = True
-            self.patch_pgn_score_to_fit_record_change_and_refresh_grid(
+            self._patch_pgn_score_to_fit_record_change_and_refresh_grid(
                 self.ui.game_games, instance
             )
 
     def generate_popup_navigation_maps(self):
         """Return tuple of widget navigation map and switch to analysis map."""
-        navigation_map = {k: v for k, v in self.get_navigation_events()}
+        navigation_map = dict(self._get_navigation_events())
         local_map = {
             EventSpec.scoresheet_to_analysis: self.analysis_current_item,
         }
         return navigation_map, local_map
 
 
-class GameDisplay(_GameDisplay, DisplayPGN, ShowPGN, Game, DataNotify):
+class GameDisplay(_GameDisplay, Game, DataNotify):
     """Display a chess game from a database allowing delete and insert."""
 
     # Notes here because GameDisplay instances used extensively to diagnose
@@ -231,22 +234,20 @@ class GameDisplay(_GameDisplay, DisplayPGN, ShowPGN, Game, DataNotify):
         if original_value.is_error_comment_present():
             original_value.set_game_source("Editor")
 
-    def create_primary_activity_popup(self):
+    def _create_primary_activity_popup(self):
         """Delegate then add close item entry and return popup menu."""
-        popup = super().create_primary_activity_popup()
-        self.add_close_item_entry_to_popup(popup)
+        popup = super()._create_primary_activity_popup()
+        self._add_close_item_entry_to_popup(popup)
         return popup
 
-    def create_select_move_popup(self):
+    def _create_select_move_popup(self):
         """Delegate then add close item entry and return popup menu."""
-        popup = super().create_select_move_popup()
-        self.add_close_item_entry_to_popup(popup)
+        popup = super()._create_select_move_popup()
+        self._add_close_item_entry_to_popup(popup)
         return popup
 
 
-class GameDisplayInsert(
-    _GameDisplay, InsertPGN, ShowPGN, GameEdit, DataNotify
-):
+class GameDisplayInsert(InsertPGN, _GameDisplay, GameEdit, DataNotify):
     """Display a chess game from a database allowing insert.
 
     GameEdit provides the widget and _GameDisplay the database interface.
@@ -273,10 +274,10 @@ class GameDisplayEdit(EditPGN, GameDisplayInsert):
         if original_value.is_error_comment_present():
             original_value.set_game_source("Editor")
 
-    # set_properties_on_grids defined so update_game_database method can be
+    # _set_properties_on_grids defined so update_game_database method can be
     # shared by repertoiredisplay.RepertoireDisplayEdit and
     # gamedisplay.GameDisplayEdit classes.
     # See class attributes pgn_score_name and pgn_score_source_name too.
-    def set_properties_on_grids(self, newkey):
+    def _set_properties_on_grids(self, newkey):
         """Set properties of widgets for newkey on all grids."""
         self.ui.set_properties_on_all_game_grids(newkey)
