@@ -2,8 +2,7 @@
 # Copyright 2009 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Functions for editing and applying font and colour options.
-"""
+"""Functions for editing and applying font and colour options."""
 
 import os
 
@@ -18,7 +17,7 @@ font_names = {
     constants.TAGS_VARIATIONS_COMMENTS_FONT,
 }
 
-_options_filename = "options"
+_OPTIONS_FILENAME = "options"
 
 
 def get_saved_options(folder):
@@ -27,19 +26,15 @@ def get_saved_options(folder):
     Return None if options file cannot be read or does not exist.
 
     """
-    optionsfilename = os.path.join(folder, _options_filename)
+    optionsfilename = os.path.join(folder, _OPTIONS_FILENAME)
     if not os.path.isfile(optionsfilename):
-        return
+        return None
     try:
-        optionsfile = open(optionsfilename, "r")
-    except:
-        return
-    defaults = dict()
-    try:
-        defaults = _extract_options(optionsfile)
-    finally:
-        optionsfile.close()
-    return defaults
+        with open(optionsfilename, "r") as optionsfile:
+            return _extract_options(optionsfile)
+    except OSError:
+        pass
+    return None
 
 
 def save_options(folder, changes):
@@ -53,45 +48,41 @@ def save_options(folder, changes):
     Leading and trailing whitespace is removed from <value> before use.
 
     """
-    optionsfilename = os.path.join(folder, _options_filename)
+    optionsfilename = os.path.join(folder, _OPTIONS_FILENAME)
     if os.path.exists(optionsfilename):
         if not os.path.isfile(optionsfilename):
             return
-    try:
-        optionsfile = open(optionsfilename, "a+")
+    with open(optionsfilename, "a+") as optionsfile:
         defaults = _extract_options(optionsfile)
-    except:
-        return
-    olddefaults, newdefaults = changes
-    try:
-        for k, v in olddefaults.items():
-            if k in font_names:
-                for ak, av in v.items():
-                    if av == newdefaults[k][ak]:
-                        del newdefaults[k][ak]
-                    elif defaults[k].get(ak) == newdefaults[k][ak]:
-                        del newdefaults[k][ak]
-                if not newdefaults[k]:
-                    del newdefaults[k]
-            elif v == newdefaults[k]:
-                del newdefaults[k]
-            elif defaults.get(k) == newdefaults[k]:
-                del newdefaults[k]
+        olddefaults, newdefaults = changes
+        for key, value in olddefaults.items():
+            if key in font_names:
+                for vikey, vivalue in value.items():
+                    if vivalue == newdefaults[key][vikey]:
+                        del newdefaults[key][vikey]
+                    elif defaults[key].get(vikey) == newdefaults[key][vikey]:
+                        del newdefaults[key][vikey]
+                if not newdefaults[key]:
+                    del newdefaults[key]
+            elif value == newdefaults[key]:
+                del newdefaults[key]
+            elif defaults.get(key) == newdefaults[key]:
+                del newdefaults[key]
         newlines = []
-        for k, v in newdefaults.items():
-            if k in font_names:
-                newlines.append("".join((k, "\n")))
-                for ak, av in v.items():
-                    if ak in fonts.integer_attributes:
-                        newlines.append("".join((ak, "=", str(av), "\n")))
+        for key, value in newdefaults.items():
+            if key in font_names:
+                newlines.append("".join((key, "\n")))
+                for vikey, vivalue in value.items():
+                    if vikey in fonts.integer_attributes:
+                        newlines.append(
+                            "".join((vikey, "=", str(vivalue), "\n"))
+                        )
                     else:
-                        newlines.append("".join((ak, "=", av, "\n")))
+                        newlines.append("".join((vikey, "=", vivalue, "\n")))
             else:
-                newlines.append("".join((k, "=", v, "\n")))
+                newlines.append("".join((key, "=", value, "\n")))
         if newlines:
             optionsfile.writelines(newlines)
-    finally:
-        optionsfile.close()
     return
 
 
@@ -116,34 +107,34 @@ def _extract_options(fileid):
         constants.LISTS_OF_GAMES_FONT: dict(),
         constants.TAGS_VARIATIONS_COMMENTS_FONT: dict(),
     }
-    for fa in fonts.modify_font_attributes:
-        defaults[fa] = None
+    for attr in fonts.modify_font_attributes:
+        defaults[attr] = None
     font_details = False
     for line in fileid.readlines():
         text = line.strip()
         if text.startswith("#"):
             continue
         try:
-            k, v = text.split("=", 1)
-        except:
-            k, v = text, ""
-        key = k.strip()
+            key_string, value_string = text.split("=", 1)
+        except ValueError:
+            key_string, value_string = text, ""
+        key = key_string.strip()
         if key in defaults:
             if key in fonts.modify_font_attributes:
                 if font_details:
-                    defaults[font_details][key] = v.strip()
+                    defaults[font_details][key] = value_string.strip()
                 continue
-            elif font_details:
+            if font_details:
                 font_attributes = defaults[font_details]
-                for fa in fonts.modify_font_attributes:
-                    if defaults[fa]:
-                        font_attributes[fa] = defaults[fa]
-                        defaults[fa] = None
+                for attr in fonts.modify_font_attributes:
+                    if defaults[attr]:
+                        font_attributes[attr] = defaults[attr]
+                        defaults[attr] = None
                 font_details = False
             if key in font_names:
                 font_details = key
             else:
-                defaults[key] = v.strip()
-    for fa in fonts.modify_font_attributes:
-        del defaults[fa]
+                defaults[key] = value_string.strip()
+    for attr in fonts.modify_font_attributes:
+        del defaults[attr]
     return defaults
