@@ -29,9 +29,8 @@ from solentware_grid.gui.dataedit import RecordEdit
 from solentware_grid.gui.datadelete import RecordDelete
 from solentware_grid.core.dataclient import DataNotify
 
-from solentware_misc.gui.exceptionhandler import ExceptionHandler
+from solentware_bind.gui.bindings import Bindings
 
-from ..core.querystatement import QueryStatement
 from .query import Query
 from .queryedit import QueryEdit
 from ..core.chessrecord import ChessDBrecordQuery
@@ -46,8 +45,9 @@ from .displaytext import (
 )
 
 
-class _QueryDisplay(ExceptionHandler, Display):
-
+class _QueryDisplay(
+    ShowText, DisplayText, Query, Display, Bindings, DataNotify
+):
     """Extend and link game selection rule to database.
 
     sourceobject - link to database.
@@ -55,7 +55,7 @@ class _QueryDisplay(ExceptionHandler, Display):
     Attribute binding_labels specifies the order navigation bindings appear
     in popup menus.
 
-    Method insert_item_database allows records to be inserted into a database
+    Method _insert_item_database allows records to be inserted into a database
     from any CQL widget.
 
     """
@@ -89,23 +89,26 @@ class _QueryDisplay(ExceptionHandler, Display):
 
     @property
     def ui_displayed_items(self):
+        """Return manager of widgets displaying a selection rule record."""
         return self.ui.selection_items
 
     @property
     def ui_configure_item_list_grid(self):
+        """Return function to configure selection rule grid to fit text."""
         return self.ui.configure_selection_grid
 
     @property
     def ui_set_item_name(self):
-        return self.ui._set_selection_name
+        """Return function to set status bar text to name of active query."""
+        return self.ui.set_selection_name
 
     @property
     def ui_set_find_item_games(self):
-        return self.ui._set_find_selection_name_games
+        """Return function to set status bar text."""
+        return self.ui.set_find_selection_name_games
 
-    def get_navigation_events(self):
-        """Return event description tuple for navigation from selection rule
-        statement."""
+    def _get_navigation_events(self):
+        """Return event description tuple for navigation from query."""
         return (
             (
                 EventSpec.navigate_to_position_grid,
@@ -136,9 +139,9 @@ class _QueryDisplay(ExceptionHandler, Display):
             ),
             (
                 EventSpec.selectiondisplay_to_previous_selection,
-                self.prior_item,
+                self._prior_item,
             ),
-            (EventSpec.selectiondisplay_to_next_selection, self.next_item),
+            (EventSpec.selectiondisplay_to_next_selection, self._next_item),
             (
                 EventSpec.navigate_to_partial_game_grid,
                 self.set_focus_partial_game_grid,
@@ -150,15 +153,22 @@ class _QueryDisplay(ExceptionHandler, Display):
 
     def delete_item_view(self, event=None):
         """Remove game selection rule item from screen."""
+        del event
         self.ui.delete_selection_rule_view(self)
 
-    def insert_item_database(self, event=None):
+    def _insert_item_database(self, event=None):
         """Add game selection rule to database."""
+        del event
         if self.ui.selection_items.active_item is None:
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
                 title="Insert Game Selection Rule",
-                message="No active game selection rule to insert into database.",
+                message="".join(
+                    (
+                        "No active game selection rule to insert ",
+                        "into database.",
+                    )
+                ),
             )
             return
 
@@ -186,14 +196,14 @@ class _QueryDisplay(ExceptionHandler, Display):
         uvpqs = updater.value.process_query_statement(
             self.get_name_query_statement_text()
         )
-        if not len(updater.value.get_name_text()):
+        if not updater.value.get_name_text():
             tkinter.messagebox.showerror(
                 parent=self.ui.get_toplevel(),
                 title="Insert Game Selection Rule",
                 message="".join(
                     (
-                        "The selection rule has no name.\n\nPlease enter it's ",
-                        "name as the first line of text.'",
+                        "The selection rule has no name.\n\nPlease enter ",
+                        "it's name as the first line of text.'",
                     )
                 ),
             )
@@ -205,7 +215,8 @@ class _QueryDisplay(ExceptionHandler, Display):
                     title="Insert Game Selection Rule",
                     message="".join(
                         (
-                            "Confirm request to add game selection rule named:\n\n",
+                            "Confirm request to add game selection rule ",
+                            "named:\n\n",
                             updater.value.get_name_text(),
                             "\n\nto database.\n\n",
                             "Note validation of the statement failed but no ",
@@ -229,7 +240,8 @@ class _QueryDisplay(ExceptionHandler, Display):
                 title="Insert Game Selection Rule",
                 message="".join(
                     (
-                        "Confirm request to add game selection rule named:\n\n",
+                        "Confirm request to add game selection rule ",
+                        "named:\n\n",
                         updater.value.get_name_text(),
                         "\n\nto database.\n\n",
                         updater.value.where_error.get_error_report(
@@ -283,35 +295,43 @@ class _QueryDisplay(ExceptionHandler, Display):
     # on_game_change() is not called, but do nothing if it is.
     def on_game_change(self, instance):
         """Prevent update from self if instance refers to same record."""
+        del instance
         if self.sourceobject is not None:
             pass
 
-    def get_list_games_events(self):
+    def _get_list_games_events(self):
         """Return tuple of event bindings to list games for selection rule."""
         return (
-            (EventSpec.display_list, self.process_and_set_selection_rule_list),
+            (
+                EventSpec.display_list,
+                self._process_and_set_selection_rule_list,
+            ),
         )
 
-    def set_database_navigation_close_item_bindings(self, switch=True):
-        super().set_database_navigation_close_item_bindings(switch=switch)
+    def _set_database_navigation_close_item_bindings(self, switch=True):
+        super()._set_database_navigation_close_item_bindings(switch=switch)
         self.set_event_bindings_score(
-            self.get_list_games_events(), switch=switch
+            self._get_list_games_events(), switch=switch
         )
 
-    def add_list_games_entry_to_popup(self, popup, index=tkinter.END):
+    def _add_list_games_entry_to_popup(self, popup):
         """Add option to list games for selection rule to popup."""
-        self.set_popup_bindings(
-            popup, self.get_list_games_events(), index=index
+        # index argument added when change in method resolution order caused
+        # this entry to be added after 'Close Item' rather than before.
+        self._set_popup_bindings(
+            popup, bindings=self._get_list_games_events(), index="Close Item"
         )
 
     def generate_popup_navigation_maps(self):
-        navigation_map = {k: v for k, v in self.get_navigation_events()}
+        """Return genenal and current widget navigation binding maps."""
+        navigation_map = dict(self._get_navigation_events())
         local_map = {}
         return navigation_map, local_map
 
-    def create_primary_activity_popup(self):
-        popup = super().create_primary_activity_popup()
-        self.add_close_item_entry_to_popup(popup)
+    def _create_primary_activity_popup(self):
+        """Delegate then add close command to popup and return popup menu."""
+        popup = super()._create_primary_activity_popup()
+        self._add_close_item_entry_to_popup(popup)
         return popup
 
     def on_selection_change(self, instance):
@@ -323,13 +343,11 @@ class _QueryDisplay(ExceptionHandler, Display):
         if instance.newrecord:
 
             # Editing an existing record.
-            value = instance.newrecord.value
             key = instance.newrecord.key
 
         else:
 
             # Inserting a new record.
-            value = instance.value
             key = instance.key
 
         if self.sourceobject is not None:
@@ -341,7 +359,7 @@ class _QueryDisplay(ExceptionHandler, Display):
                 self.blockchange = True
 
     def get_text_for_statusbar(self):
-        """ """
+        """Return 'Please wait ..' message for status bar."""
         return "".join(
             (
                 "Please wait while finding games for game selection rule ",
@@ -350,7 +368,7 @@ class _QueryDisplay(ExceptionHandler, Display):
         )
 
     def get_selection_text_for_statusbar(self):
-        """ """
+        """Return query name text for display in status bar."""
         return self.query_statement.get_name_text()
 
     # This method added so it can be used in _cycle_items which then becomes
@@ -365,8 +383,9 @@ class _QueryDisplay(ExceptionHandler, Display):
         """
         self.refresh_game_list()
 
-    def process_and_set_selection_rule_list(self, event=None):
+    def _process_and_set_selection_rule_list(self, event=None):
         """Display games matching edited game selection rule."""
+        del event
         if self.ui.base_games.datasource:
             self.query_statement.set_database(
                 self.ui.base_games.datasource.dbhome
@@ -388,24 +407,25 @@ class _QueryDisplay(ExceptionHandler, Display):
         return "break"
 
 
-class QueryDisplay(_QueryDisplay, DisplayText, ShowText, Query, DataNotify):
-
+class QueryDisplay(_QueryDisplay, Query, DataNotify):
     """Display game selection rule from database and allow delete and insert.
 
-    Method delete_item_database allows records to be deleted from a database.
+    Method _delete_item_database allows records to be deleted from a database.
 
     """
 
     # QueryDisplay has this method, but CQLDisplay does not, because the game
     # list area is shared with the main game list and the index lists.
     # Generating the game list on demand may be necessary at any time.
-    def create_primary_activity_popup(self):
-        popup = super().create_primary_activity_popup()
-        self.add_list_games_entry_to_popup(popup, index="Close Item")
+    def _create_primary_activity_popup(self):
+        """Delegate then add close command to popup and return popup menu."""
+        popup = super()._create_primary_activity_popup()
+        self._add_list_games_entry_to_popup(popup)
         return popup
 
-    def delete_item_database(self, event=None):
+    def _delete_item_database(self, event=None):
         """Remove game selection rule from database."""
+        del event
         if self.ui.database is None:
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
@@ -463,13 +483,14 @@ class QueryDisplay(_QueryDisplay, DisplayText, ShowText, Query, DataNotify):
             message="Confirm request to delete game selection rule.",
         ):
             return
-        s = self.query_statement
-        if s.where_error is not None:
-            v = self.sourceobject.value
+        statement = self.query_statement
+        if statement.where_error is not None:
+            value = self.sourceobject.value
             if (
-                s.get_name_text() != v.get_name_text()
-                or s.where_error != v.where_error
-                or s.get_query_statement_text() != v.get_query_statement_text()
+                statement.get_name_text() != value.get_name_text()
+                or statement.where_error != value.where_error
+                or statement.get_query_statement_text()
+                != value.get_query_statement_text()
             ):
                 tkinter.messagebox.showinfo(
                     parent=self.ui.get_toplevel(),
@@ -504,9 +525,8 @@ class QueryDisplay(_QueryDisplay, DisplayText, ShowText, Query, DataNotify):
 
 
 class QueryDisplayInsert(
-    _QueryDisplay, ListGamesText, InsertText, ShowText, QueryEdit, DataNotify
+    ListGamesText, InsertText, _QueryDisplay, QueryEdit, DataNotify
 ):
-
     """Display game selection rule from database allowing insert.
 
     QueryEdit provides the widget and _QueryDisplay the database interface.
@@ -523,15 +543,15 @@ class QueryDisplayInsert(
 
 
 class QueryDisplayEdit(EditText, QueryDisplayInsert):
-
     """Display game selection rule from database allowing edit and insert.
 
-    Method update_item_database allows records on the database to be amended.
+    Method _update_item_database allows records on the database to be amended.
 
     """
 
-    def update_item_database(self, event=None):
+    def _update_item_database(self, event=None):
         """Modify existing game selection rule record."""
+        del event
         if self.ui.database is None:
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
@@ -544,7 +564,12 @@ class QueryDisplayEdit(EditText, QueryDisplayInsert):
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
                 title="Edit Game Selection Rule",
-                message="Cannot edit game selection rule:\n\nRule list hidden.",
+                message="".join(
+                    (
+                        "Cannot edit game selection rule:\n\n",
+                        "Rule list hidden.",
+                    )
+                ),
             )
             return
         if self.sourceobject is None:
@@ -588,14 +613,14 @@ class QueryDisplayEdit(EditText, QueryDisplayInsert):
         uvpqs = updater.value.process_query_statement(
             self.get_name_query_statement_text()
         )
-        if not len(updater.value.get_name_text()):
+        if not updater.value.get_name_text():
             tkinter.messagebox.showerror(
                 parent=self.ui.get_toplevel(),
                 title="Edit Game Selection Rule",
                 message="".join(
                     (
-                        "The selection rule has no name.\n\nPlease enter it's ",
-                        "name as the first line of text.'",
+                        "The selection rule has no name.\n\nPlease enter ",
+                        "it's name as the first line of text.'",
                     )
                 ),
             )
@@ -632,7 +657,8 @@ class QueryDisplayEdit(EditText, QueryDisplayInsert):
                 title="Edit Game Selection Rule",
                 message="".join(
                     (
-                        "Confirm request to edit game selection rule named:\n\n",
+                        "Confirm request to edit game selection rule ",
+                        "named:\n\n",
                         updater.value.get_name_text(),
                         "\n\nto database.\n\n",
                         updater.value.where_error.get_error_report(
