@@ -8,6 +8,6 @@
 if __name__ == "__main__":
 
     from .directory_widget import DirectoryWidget
-    from ..db.chessdbdu import chess_dbdu
+    from ..db.chessdbdu import chess_database_du
 
-    DirectoryWidget(chess_dbdu, "db")
+    DirectoryWidget(chess_database_du, "db")
