@@ -5,9 +5,9 @@
 """Import directory of PGN files with dpt.chessdptdu to database."""
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
     from .directory_widget import DirectoryWidget
     from ..dpt.chessdptdu import chess_dptdu
 
-    DirectoryWidget(chess_dptdu, 'dpt')
+    DirectoryWidget(chess_dptdu, "dpt")
