@@ -8,6 +8,6 @@
 if __name__ == "__main__":
 
     from .directory_widget import DirectoryWidget
-    from ..gnu.chessgnudu import chess_gnudu
+    from ..gnu.chessgnudu import chess_database_du
 
-    DirectoryWidget(chess_gnudu, "dbm.gnu")
+    DirectoryWidget(chess_database_du, "dbm.gnu")
