@@ -18,6 +18,6 @@ too.
 if __name__ == "__main__":
 
     from .directory_widget import DirectoryWidget
-    from ..ndbm.chessndbmdu import chess_ndbmdu
+    from ..ndbm.chessndbmdu import chess_database_du
 
-    DirectoryWidget(chess_ndbmdu, "dbm.ndbm")
+    DirectoryWidget(chess_database_du, "dbm.ndbm")
