@@ -5,9 +5,9 @@
 """Import PGN file with ndbm.chessndbmdu to database."""
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
     from .file_widget import FileWidget
     from ..ndbm.chessndbmdu import ChessDatabase
 
-    FileWidget(ChessDatabase, 'dbm.ndbm')
+    FileWidget(ChessDatabase, "dbm.ndbm")
