@@ -5,9 +5,9 @@
 """Import PGN file with sqlite.chesssqlite3du to database."""
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
     from .file_widget import FileWidget
     from ..sqlite.chesssqlite3du import ChessDatabase
 
-    FileWidget(ChessDatabase, 'sqlite3')
+    FileWidget(ChessDatabase, "sqlite3")
