@@ -8,6 +8,6 @@
 if __name__ == "__main__":
 
     from .directory_widget import DirectoryWidget
-    from ..vedis.chessvedisdu import chess_vedisdu
+    from ..vedis.chessvedisdu import chess_database_du
 
-    DirectoryWidget(chess_vedisdu, "vedis")
+    DirectoryWidget(chess_database_du, "vedis")
