@@ -2,8 +2,11 @@
 # Copyright 2016 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Print names in games_Black and games_White records where the name with
-',' and '.' ripped out is not the name in the record."""
+"""Sample database traversal of Games file in Berkeley DB database.
+
+Print names in games_Black and games_White records where the name with
+',' and '.' ripped out is not the name in the record.
+"""
 
 
 if __name__ == "__main__":
@@ -12,7 +15,7 @@ if __name__ == "__main__":
     import ast
     import re
 
-    re_normalize_player_name = re.compile("([^,\.\s]+(?:,|\.)?)(?:\s*)")
+    re_normalize_player_name = re.compile(r"([^,\.\s]+(?:,|\.)?)(?:\s*)")
 
     file_dbname_map = {
         "games_Black": "Black",
