@@ -14,7 +14,7 @@ class ChessunqliteduError(Exception):
     """Exception class for chessunqlitedu module."""
 
 
-def chess_unqlitedu(dbpath, *args, **kwargs):
+def chess_database_du(dbpath, *args, estimated_number_of_games=0, **kwargs):
     """Open database, import games and close database."""
     chess_du(ChessDatabase(dbpath, allowcreate=True), *args, **kwargs)
 
@@ -22,10 +22,6 @@ def chess_unqlitedu(dbpath, *args, **kwargs):
     return True
 
 
-# 'def chess_unqlitedu' will be changed to 'def chess_database_du' some time.
-chess_database_du = chess_unqlitedu
-
-
 class ChessDatabase(Alldu, Litedu, unqlitedu_database.Database):
     """Provide custom deferred update for a database of games of chess."""
 
