@@ -14,7 +14,7 @@ class ChessvedisduError(Exception):
     """Exception class for chessvedisdu module."""
 
 
-def chess_vedisdu(dbpath, *args, **kwargs):
+def chess_database_du(dbpath, *args, estimated_number_of_games=0, **kwargs):
     """Open database, import games and close database."""
     chess_du(ChessDatabase(dbpath, allowcreate=True), *args, **kwargs)
 
@@ -22,10 +22,6 @@ def chess_vedisdu(dbpath, *args, **kwargs):
     return True
 
 
-# 'def chess_vedisdu' will be changed to 'def chess_database_du' at some time.
-chess_database_du = chess_vedisdu
-
-
 class ChessDatabase(Alldu, Litedu, vedisdu_database.Database):
     """Provide custom deferred update for a database of games of chess."""
 
